/* gitg-preferences-dialog.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-preferences-dialog.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2012 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include "libgitg-ext.h"
#include <stdlib.h>
#include <string.h>
#include <libpeas/peas.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_TYPE_PREFERENCES_DIALOG (gitg_preferences_dialog_get_type ())
#define GITG_PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_PREFERENCES_DIALOG, GitgPreferencesDialog))
#define GITG_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_PREFERENCES_DIALOG, GitgPreferencesDialogClass))
#define GITG_IS_PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_PREFERENCES_DIALOG))
#define GITG_IS_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_PREFERENCES_DIALOG))
#define GITG_PREFERENCES_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_PREFERENCES_DIALOG, GitgPreferencesDialogClass))

typedef struct _GitgPreferencesDialog GitgPreferencesDialog;
typedef struct _GitgPreferencesDialogClass GitgPreferencesDialogClass;
typedef struct _GitgPreferencesDialogPrivate GitgPreferencesDialogPrivate;
enum  {
	GITG_PREFERENCES_DIALOG_0_PROPERTY,
	GITG_PREFERENCES_DIALOG_NUM_PROPERTIES
};
static GParamSpec* gitg_preferences_dialog_properties[GITG_PREFERENCES_DIALOG_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block51Data Block51Data;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

#define GITG_TYPE_PLUGINS_ENGINE (gitg_plugins_engine_get_type ())
#define GITG_PLUGINS_ENGINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_PLUGINS_ENGINE, GitgPluginsEngine))
#define GITG_PLUGINS_ENGINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_PLUGINS_ENGINE, GitgPluginsEngineClass))
#define GITG_IS_PLUGINS_ENGINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_PLUGINS_ENGINE))
#define GITG_IS_PLUGINS_ENGINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_PLUGINS_ENGINE))
#define GITG_PLUGINS_ENGINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_PLUGINS_ENGINE, GitgPluginsEngineClass))

typedef struct _GitgPluginsEngine GitgPluginsEngine;
typedef struct _GitgPluginsEngineClass GitgPluginsEngineClass;

#define GITG_TYPE_PREFERENCES_INTERFACE (gitg_preferences_interface_get_type ())
#define GITG_PREFERENCES_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_PREFERENCES_INTERFACE, GitgPreferencesInterface))
#define GITG_PREFERENCES_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_PREFERENCES_INTERFACE, GitgPreferencesInterfaceClass))
#define GITG_IS_PREFERENCES_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_PREFERENCES_INTERFACE))
#define GITG_IS_PREFERENCES_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_PREFERENCES_INTERFACE))
#define GITG_PREFERENCES_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_PREFERENCES_INTERFACE, GitgPreferencesInterfaceClass))

typedef struct _GitgPreferencesInterface GitgPreferencesInterface;
typedef struct _GitgPreferencesInterfaceClass GitgPreferencesInterfaceClass;

#define GITG_TYPE_PREFERENCES_HISTORY (gitg_preferences_history_get_type ())
#define GITG_PREFERENCES_HISTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_PREFERENCES_HISTORY, GitgPreferencesHistory))
#define GITG_PREFERENCES_HISTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_PREFERENCES_HISTORY, GitgPreferencesHistoryClass))
#define GITG_IS_PREFERENCES_HISTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_PREFERENCES_HISTORY))
#define GITG_IS_PREFERENCES_HISTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_PREFERENCES_HISTORY))
#define GITG_PREFERENCES_HISTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_PREFERENCES_HISTORY, GitgPreferencesHistoryClass))

typedef struct _GitgPreferencesHistory GitgPreferencesHistory;
typedef struct _GitgPreferencesHistoryClass GitgPreferencesHistoryClass;

#define GITG_TYPE_PREFERENCES_COMMIT (gitg_preferences_commit_get_type ())
#define GITG_PREFERENCES_COMMIT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_PREFERENCES_COMMIT, GitgPreferencesCommit))
#define GITG_PREFERENCES_COMMIT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_PREFERENCES_COMMIT, GitgPreferencesCommitClass))
#define GITG_IS_PREFERENCES_COMMIT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_PREFERENCES_COMMIT))
#define GITG_IS_PREFERENCES_COMMIT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_PREFERENCES_COMMIT))
#define GITG_PREFERENCES_COMMIT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_PREFERENCES_COMMIT, GitgPreferencesCommitClass))

typedef struct _GitgPreferencesCommit GitgPreferencesCommit;
typedef struct _GitgPreferencesCommitClass GitgPreferencesCommitClass;

struct _GitgPreferencesDialog {
	GtkDialog parent_instance;
	GitgPreferencesDialogPrivate * priv;
};

struct _GitgPreferencesDialogClass {
	GtkDialogClass parent_class;
};

struct _GitgPreferencesDialogPrivate {
	GtkNotebook* d_notebook;
};

struct _Block51Data {
	int _ref_count_;
	GitgPreferencesDialog* self;
	GHashTable* pages;
};

static gint GitgPreferencesDialog_private_offset;
static gpointer gitg_preferences_dialog_parent_class = NULL;
static GtkBuildableIface * gitg_preferences_dialog_gtk_buildable_parent_iface = NULL;

VALA_EXTERN GType gitg_preferences_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgPreferencesDialog, g_object_unref)
static void gitg_preferences_dialog_real_parser_finished (GtkBuildable* base,
                                                   GtkBuilder* builder);
VALA_EXTERN void gitg_preferences_dialog_populate (GitgPreferencesDialog* self);
static void gitg_preferences_dialog_add_page (GitgPreferencesDialog* self,
                                       GitgExtPreferences* pref,
                                       GHashTable* pages);
static Block51Data* block51_data_ref (Block51Data* _data51_);
static void block51_data_unref (void * _userdata_);
VALA_EXTERN GType gitg_plugins_engine_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgPluginsEngine, g_object_unref)
VALA_EXTERN GitgPluginsEngine* gitg_plugins_engine_get_default (void);
static void _g_free0_ (gpointer var);
static void _g_object_unref0_ (gpointer var);
VALA_EXTERN GitgPreferencesInterface* gitg_preferences_interface_new (void);
VALA_EXTERN GitgPreferencesInterface* gitg_preferences_interface_construct (GType object_type);
VALA_EXTERN GType gitg_preferences_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgPreferencesInterface, g_object_unref)
VALA_EXTERN GitgPreferencesHistory* gitg_preferences_history_new (void);
VALA_EXTERN GitgPreferencesHistory* gitg_preferences_history_construct (GType object_type);
VALA_EXTERN GType gitg_preferences_history_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgPreferencesHistory, g_object_unref)
VALA_EXTERN GitgPreferencesCommit* gitg_preferences_commit_new (void);
VALA_EXTERN GitgPreferencesCommit* gitg_preferences_commit_construct (GType object_type);
VALA_EXTERN GType gitg_preferences_commit_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgPreferencesCommit, g_object_unref)
static void __lambda148_ (Block51Data* _data51_,
                   PeasExtensionSet* s,
                   PeasPluginInfo* info,
                   PeasExtension* e);
static void ___lambda148__peas_extension_set_foreach_func (PeasExtensionSet* set,
                                                    PeasPluginInfo* info,
                                                    PeasExtension* exten,
                                                    gpointer self);
VALA_EXTERN GitgPreferencesDialog* gitg_preferences_dialog_new (void);
VALA_EXTERN GitgPreferencesDialog* gitg_preferences_dialog_construct (GType object_type);
static void gitg_preferences_dialog_finalize (GObject * obj);
static GType gitg_preferences_dialog_get_type_once (void);

static inline gpointer
gitg_preferences_dialog_get_instance_private (GitgPreferencesDialog* self)
{
	return G_STRUCT_MEMBER_P (self, GitgPreferencesDialog_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
gitg_preferences_dialog_real_parser_finished (GtkBuildable* base,
                                              GtkBuilder* builder)
{
	GitgPreferencesDialog * self;
	GObject* _tmp0_;
	GtkNotebook* _tmp1_;
	self = (GitgPreferencesDialog*) base;
	g_return_if_fail (builder != NULL);
	_tmp0_ = gtk_builder_get_object (builder, "notebook_elements");
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_notebook_get_type ()) ? ((GtkNotebook*) _tmp0_) : NULL);
	_g_object_unref0 (self->priv->d_notebook);
	self->priv->d_notebook = _tmp1_;
	gitg_preferences_dialog_populate (self);
	gitg_preferences_dialog_gtk_buildable_parent_iface->parser_finished ((GtkBuildable*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), builder);
}

static void
gitg_preferences_dialog_add_page (GitgPreferencesDialog* self,
                                  GitgExtPreferences* pref,
                                  GHashTable* pages)
{
	GtkBox* page = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gconstpointer _tmp3_ = NULL;
	gboolean _tmp4_;
	GtkBox* _tmp5_;
	gboolean _tmp6_;
	GtkBox* _tmp22_;
	GtkWidget* _tmp23_;
	GtkWidget* _tmp24_;
	GtkWidget* _tmp25_;
	GtkNotebook* _tmp26_;
	GtkBox* _tmp27_;
	GValue _tmp28_ = {0};
	g_return_if_fail (self != NULL);
	g_return_if_fail (pref != NULL);
	g_return_if_fail (pages != NULL);
	_tmp0_ = gitg_ext_preferences_get_id (pref);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp4_ = g_hash_table_lookup_extended (pages, _tmp2_, NULL, &_tmp3_);
	_g_object_unref0 (page);
	_tmp5_ = _g_object_ref0 ((GtkBox*) _tmp3_);
	page = _tmp5_;
	_tmp6_ = !_tmp4_;
	_g_free0 (_tmp2_);
	if (_tmp6_) {
		GtkBox* _tmp7_;
		GtkBox* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GtkBox* _tmp11_;
		GtkBox* _tmp12_;
		GtkLabel* lbl = NULL;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		GtkLabel* _tmp16_;
		GtkLabel* _tmp17_;
		GtkLabel* _tmp18_;
		GtkNotebook* _tmp19_;
		GtkBox* _tmp20_;
		GtkLabel* _tmp21_;
		_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
		g_object_ref_sink (_tmp7_);
		_g_object_unref0 (page);
		page = _tmp7_;
		_tmp8_ = page;
		gtk_widget_show ((GtkWidget*) _tmp8_);
		_tmp9_ = gitg_ext_preferences_get_id (pref);
		_tmp10_ = _tmp9_;
		_tmp11_ = page;
		_tmp12_ = _g_object_ref0 (_tmp11_);
		g_hash_table_insert (pages, _tmp10_, _tmp12_);
		_tmp13_ = gitg_ext_preferences_get_display_name (pref);
		_tmp14_ = _tmp13_;
		_tmp15_ = _tmp14_;
		_tmp16_ = (GtkLabel*) gtk_label_new (_tmp15_);
		g_object_ref_sink (_tmp16_);
		_tmp17_ = _tmp16_;
		_g_free0 (_tmp15_);
		lbl = _tmp17_;
		_tmp18_ = lbl;
		gtk_widget_show ((GtkWidget*) _tmp18_);
		_tmp19_ = self->priv->d_notebook;
		_tmp20_ = page;
		_tmp21_ = lbl;
		gtk_notebook_append_page (_tmp19_, (GtkWidget*) _tmp20_, (GtkWidget*) _tmp21_);
		_g_object_unref0 (lbl);
	}
	_tmp22_ = page;
	_tmp23_ = gitg_ext_preferences_get_widget (pref);
	_tmp24_ = _tmp23_;
	_tmp25_ = _tmp24_;
	gtk_container_add ((GtkContainer*) _tmp22_, _tmp25_);
	_g_object_unref0 (_tmp25_);
	_tmp26_ = self->priv->d_notebook;
	_tmp27_ = page;
	g_value_init (&_tmp28_, G_TYPE_BOOLEAN);
	g_value_set_boolean (&_tmp28_, TRUE);
	gtk_container_child_set_property ((GtkContainer*) _tmp26_, (GtkWidget*) _tmp27_, "tab-expand", &_tmp28_);
	G_IS_VALUE (&_tmp28_) ? (g_value_unset (&_tmp28_), NULL) : NULL;
	_g_object_unref0 (page);
}

static Block51Data*
block51_data_ref (Block51Data* _data51_)
{
	g_atomic_int_inc (&_data51_->_ref_count_);
	return _data51_;
}

static void
block51_data_unref (void * _userdata_)
{
	Block51Data* _data51_;
	_data51_ = (Block51Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data51_->_ref_count_)) {
		GitgPreferencesDialog* self;
		self = _data51_->self;
		_g_hash_table_unref0 (_data51_->pages);
		_g_object_unref0 (self);
		g_slice_free (Block51Data, _data51_);
	}
}

static void
_g_free0_ (gpointer var)
{
	var = (g_free (var), NULL);
}

static void
_g_object_unref0_ (gpointer var)
{
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
}

static void
__lambda148_ (Block51Data* _data51_,
              PeasExtensionSet* s,
              PeasPluginInfo* info,
              PeasExtension* e)
{
	GitgPreferencesDialog* self;
	self = _data51_->self;
	g_return_if_fail (s != NULL);
	g_return_if_fail (info != NULL);
	g_return_if_fail (e != NULL);
	gitg_preferences_dialog_add_page (self, G_TYPE_CHECK_INSTANCE_TYPE (e, GITG_EXT_TYPE_PREFERENCES) ? ((GitgExtPreferences*) e) : NULL, _data51_->pages);
}

static void
___lambda148__peas_extension_set_foreach_func (PeasExtensionSet* set,
                                               PeasPluginInfo* info,
                                               PeasExtension* exten,
                                               gpointer self)
{
	__lambda148_ (self, set, info, exten);
}

void
gitg_preferences_dialog_populate (GitgPreferencesDialog* self)
{
	Block51Data* _data51_;
	GitgPluginsEngine* engine = NULL;
	GitgPluginsEngine* _tmp0_;
	PeasExtensionSet* ext = NULL;
	PeasExtensionSet* _tmp1_;
	GHashFunc _tmp2_;
	GEqualFunc _tmp3_;
	GHashTable* _tmp4_;
	GitgPreferencesInterface* _tmp5_;
	GitgPreferencesInterface* _tmp6_;
	GitgPreferencesHistory* _tmp7_;
	GitgPreferencesHistory* _tmp8_;
	GitgPreferencesCommit* _tmp9_;
	GitgPreferencesCommit* _tmp10_;
	g_return_if_fail (self != NULL);
	_data51_ = g_slice_new0 (Block51Data);
	_data51_->_ref_count_ = 1;
	_data51_->self = g_object_ref (self);
	_tmp0_ = gitg_plugins_engine_get_default ();
	engine = _tmp0_;
	_tmp1_ = peas_extension_set_new ((PeasEngine*) engine, GITG_EXT_TYPE_PREFERENCES, NULL);
	ext = _tmp1_;
	_tmp2_ = g_str_hash;
	_tmp3_ = g_str_equal;
	_tmp4_ = g_hash_table_new_full (_tmp2_, _tmp3_, _g_free0_, _g_object_unref0_);
	_data51_->pages = _tmp4_;
	_tmp5_ = gitg_preferences_interface_new ();
	g_object_ref_sink (_tmp5_);
	_tmp6_ = _tmp5_;
	gitg_preferences_dialog_add_page (self, (GitgExtPreferences*) _tmp6_, _data51_->pages);
	_g_object_unref0 (_tmp6_);
	_tmp7_ = gitg_preferences_history_new ();
	g_object_ref_sink (_tmp7_);
	_tmp8_ = _tmp7_;
	gitg_preferences_dialog_add_page (self, (GitgExtPreferences*) _tmp8_, _data51_->pages);
	_g_object_unref0 (_tmp8_);
	_tmp9_ = gitg_preferences_commit_new ();
	g_object_ref_sink (_tmp9_);
	_tmp10_ = _tmp9_;
	gitg_preferences_dialog_add_page (self, (GitgExtPreferences*) _tmp10_, _data51_->pages);
	_g_object_unref0 (_tmp10_);
	peas_extension_set_foreach (ext, ___lambda148__peas_extension_set_foreach_func, _data51_);
	_g_object_unref0 (ext);
	_g_object_unref0 (engine);
	block51_data_unref (_data51_);
	_data51_ = NULL;
}

GitgPreferencesDialog*
gitg_preferences_dialog_construct (GType object_type)
{
	GitgPreferencesDialog * self = NULL;
	self = (GitgPreferencesDialog*) g_object_new (object_type, NULL);
	return self;
}

GitgPreferencesDialog*
gitg_preferences_dialog_new (void)
{
	return gitg_preferences_dialog_construct (GITG_TYPE_PREFERENCES_DIALOG);
}

static void
gitg_preferences_dialog_class_init (GitgPreferencesDialogClass * klass,
                                    gpointer klass_data)
{
	gitg_preferences_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgPreferencesDialog_private_offset);
	G_OBJECT_CLASS (klass)->finalize = gitg_preferences_dialog_finalize;
}

static void
gitg_preferences_dialog_gtk_buildable_interface_init (GtkBuildableIface * iface,
                                                      gpointer iface_data)
{
	gitg_preferences_dialog_gtk_buildable_parent_iface = g_type_interface_peek_parent (iface);
	iface->parser_finished = (void (*) (GtkBuildable*, GtkBuilder*)) gitg_preferences_dialog_real_parser_finished;
}

static void
gitg_preferences_dialog_instance_init (GitgPreferencesDialog * self,
                                       gpointer klass)
{
	self->priv = gitg_preferences_dialog_get_instance_private (self);
}

static void
gitg_preferences_dialog_finalize (GObject * obj)
{
	GitgPreferencesDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_PREFERENCES_DIALOG, GitgPreferencesDialog);
	_g_object_unref0 (self->priv->d_notebook);
	G_OBJECT_CLASS (gitg_preferences_dialog_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_preferences_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgPreferencesDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_preferences_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgPreferencesDialog), 0, (GInstanceInitFunc) gitg_preferences_dialog_instance_init, NULL };
	static const GInterfaceInfo gtk_buildable_info = { (GInterfaceInitFunc) gitg_preferences_dialog_gtk_buildable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gitg_preferences_dialog_type_id;
	gitg_preferences_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "GitgPreferencesDialog", &g_define_type_info, 0);
	g_type_add_interface_static (gitg_preferences_dialog_type_id, gtk_buildable_get_type (), &gtk_buildable_info);
	GitgPreferencesDialog_private_offset = g_type_add_instance_private (gitg_preferences_dialog_type_id, sizeof (GitgPreferencesDialogPrivate));
	return gitg_preferences_dialog_type_id;
}

GType
gitg_preferences_dialog_get_type (void)
{
	static gsize gitg_preferences_dialog_type_id__once = 0;
	if (g_once_init_enter (&gitg_preferences_dialog_type_id__once)) {
		GType gitg_preferences_dialog_type_id;
		gitg_preferences_dialog_type_id = gitg_preferences_dialog_get_type_once ();
		g_once_init_leave (&gitg_preferences_dialog_type_id__once, gitg_preferences_dialog_type_id);
	}
	return gitg_preferences_dialog_type_id__once;
}

