/* gitg-ext-ui.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-ext-ui.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2012 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include "libgitg-ext.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gee.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdarg.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _GitgExtParamSpecUI GitgExtParamSpecUI;

struct _GitgExtParamSpecUI {
	GParamSpec parent_instance;
};

static gpointer gitg_ext_ui_parent_class = NULL;

static void gitg_ext_ui_finalize (GitgExtUI * obj);
static GType gitg_ext_ui_get_type_once (void);

GeeHashMap*
gitg_ext_ui_from_builder (const gchar* path,
                          ...)
{
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	GeeHashMap* ret = NULL;
	GeeHashMap* _tmp6_;
	va_list l = {0};
	GError* _inner_error0_ = NULL;
	GeeHashMap* result;
	g_return_val_if_fail (path != NULL, NULL);
	_tmp0_ = gtk_builder_new ();
	builder = _tmp0_;
	{
		GtkBuilder* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		_tmp1_ = builder;
		_tmp2_ = g_strconcat ("/org/gnome/gitg/", path, NULL);
		_tmp3_ = _tmp2_;
		gtk_builder_add_from_resource (_tmp1_, _tmp3_, &_inner_error0_);
		_g_free0 (_tmp3_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp4_;
		const gchar* _tmp5_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp4_ = e;
		_tmp5_ = _tmp4_->message;
		g_warning ("gitg-ext-ui.vala:34: Failed to load ui: %s", _tmp5_);
		result = NULL;
		_g_error_free0 (e);
		_g_object_unref0 (builder);
		return result;
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		_g_object_unref0 (builder);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return NULL;
	}
	_tmp6_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_OBJECT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	ret = _tmp6_;
	va_start (l, path);
	while (TRUE) {
		gchar* id = NULL;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		const gchar* _tmp9_;
		GeeHashMap* _tmp10_;
		const gchar* _tmp11_;
		GtkBuilder* _tmp12_;
		const gchar* _tmp13_;
		GObject* _tmp14_;
		_tmp7_ = va_arg (l, gchar*);
		_tmp8_ = g_strdup (_tmp7_);
		id = _tmp8_;
		_tmp9_ = id;
		if (_tmp9_ == NULL) {
			_g_free0 (id);
			break;
		}
		_tmp10_ = ret;
		_tmp11_ = id;
		_tmp12_ = builder;
		_tmp13_ = id;
		_tmp14_ = gtk_builder_get_object (_tmp12_, _tmp13_);
		gee_abstract_map_set ((GeeAbstractMap*) _tmp10_, _tmp11_, _tmp14_);
		_g_free0 (id);
	}
	result = ret;
	va_end (l);
	_g_object_unref0 (builder);
	return result;
}

GitgExtUI*
gitg_ext_ui_construct (GType object_type)
{
	GitgExtUI* self = NULL;
	self = (GitgExtUI*) g_type_create_instance (object_type);
	return self;
}

GitgExtUI*
gitg_ext_ui_new (void)
{
	return gitg_ext_ui_construct (GITG_EXT_TYPE_UI);
}

static void
gitg_ext_value_ui_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
gitg_ext_value_ui_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		gitg_ext_ui_unref (value->data[0].v_pointer);
	}
}

static void
gitg_ext_value_ui_copy_value (const GValue* src_value,
                              GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = gitg_ext_ui_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
gitg_ext_value_ui_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
gitg_ext_value_ui_collect_value (GValue* value,
                                 guint n_collect_values,
                                 GTypeCValue* collect_values,
                                 guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		GitgExtUI * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = gitg_ext_ui_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
gitg_ext_value_ui_lcopy_value (const GValue* value,
                               guint n_collect_values,
                               GTypeCValue* collect_values,
                               guint collect_flags)
{
	GitgExtUI ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = gitg_ext_ui_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
gitg_ext_param_spec_ui (const gchar* name,
                        const gchar* nick,
                        const gchar* blurb,
                        GType object_type,
                        GParamFlags flags)
{
	GitgExtParamSpecUI* spec;
	g_return_val_if_fail (g_type_is_a (object_type, GITG_EXT_TYPE_UI), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
gitg_ext_value_get_ui (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GITG_EXT_TYPE_UI), NULL);
	return value->data[0].v_pointer;
}

void
gitg_ext_value_set_ui (GValue* value,
                       gpointer v_object)
{
	GitgExtUI * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GITG_EXT_TYPE_UI));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GITG_EXT_TYPE_UI));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		gitg_ext_ui_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gitg_ext_ui_unref (old);
	}
}

void
gitg_ext_value_take_ui (GValue* value,
                        gpointer v_object)
{
	GitgExtUI * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GITG_EXT_TYPE_UI));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GITG_EXT_TYPE_UI));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gitg_ext_ui_unref (old);
	}
}

static void
gitg_ext_ui_class_init (GitgExtUIClass * klass,
                        gpointer klass_data)
{
	gitg_ext_ui_parent_class = g_type_class_peek_parent (klass);
	((GitgExtUIClass *) klass)->finalize = gitg_ext_ui_finalize;
}

static void
gitg_ext_ui_instance_init (GitgExtUI * self,
                           gpointer klass)
{
	self->ref_count = 1;
}

static void
gitg_ext_ui_finalize (GitgExtUI * obj)
{
	GitgExtUI * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_EXT_TYPE_UI, GitgExtUI);
	g_signal_handlers_destroy (self);
}

 G_GNUC_NO_INLINE static GType
gitg_ext_ui_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { gitg_ext_value_ui_init, gitg_ext_value_ui_free_value, gitg_ext_value_ui_copy_value, gitg_ext_value_ui_peek_pointer, "p", gitg_ext_value_ui_collect_value, "p", gitg_ext_value_ui_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (GitgExtUIClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_ext_ui_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgExtUI), 0, (GInstanceInitFunc) gitg_ext_ui_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType gitg_ext_ui_type_id;
	gitg_ext_ui_type_id = g_type_register_fundamental (g_type_fundamental_next (), "GitgExtUI", &g_define_type_info, &g_define_type_fundamental_info, 0);
	return gitg_ext_ui_type_id;
}

GType
gitg_ext_ui_get_type (void)
{
	static gsize gitg_ext_ui_type_id__once = 0;
	if (g_once_init_enter (&gitg_ext_ui_type_id__once)) {
		GType gitg_ext_ui_type_id;
		gitg_ext_ui_type_id = gitg_ext_ui_get_type_once ();
		g_once_init_leave (&gitg_ext_ui_type_id__once, gitg_ext_ui_type_id);
	}
	return gitg_ext_ui_type_id__once;
}

gpointer
gitg_ext_ui_ref (gpointer instance)
{
	GitgExtUI * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
gitg_ext_ui_unref (gpointer instance)
{
	GitgExtUI * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		GITG_EXT_UI_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

