/* gitg-diff-view-file-renderer-binary.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-diff-view-file-renderer-binary.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2016 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <libgit2-glib/ggit.h>
#include <gee.h>
#include <glib.h>
#include "libgitg.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define GITG_TYPE_DIFF_VIEW_FILE_RENDERER (gitg_diff_view_file_renderer_get_type ())
#define GITG_DIFF_VIEW_FILE_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER, GitgDiffViewFileRenderer))
#define GITG_IS_DIFF_VIEW_FILE_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER))
#define GITG_DIFF_VIEW_FILE_RENDERER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER, GitgDiffViewFileRendererIface))

typedef struct _GitgDiffViewFileRenderer GitgDiffViewFileRenderer;
typedef struct _GitgDiffViewFileRendererIface GitgDiffViewFileRendererIface;

#define GITG_TYPE_DIFF_VIEW_FILE_RENDERER_BINARY (gitg_diff_view_file_renderer_binary_get_type ())
#define GITG_DIFF_VIEW_FILE_RENDERER_BINARY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_BINARY, GitgDiffViewFileRendererBinary))
#define GITG_DIFF_VIEW_FILE_RENDERER_BINARY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_BINARY, GitgDiffViewFileRendererBinaryClass))
#define GITG_IS_DIFF_VIEW_FILE_RENDERER_BINARY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_BINARY))
#define GITG_IS_DIFF_VIEW_FILE_RENDERER_BINARY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_BINARY))
#define GITG_DIFF_VIEW_FILE_RENDERER_BINARY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_BINARY, GitgDiffViewFileRendererBinaryClass))

typedef struct _GitgDiffViewFileRendererBinary GitgDiffViewFileRendererBinary;
typedef struct _GitgDiffViewFileRendererBinaryClass GitgDiffViewFileRendererBinaryClass;
typedef struct _GitgDiffViewFileRendererBinaryPrivate GitgDiffViewFileRendererBinaryPrivate;
enum  {
	GITG_DIFF_VIEW_FILE_RENDERER_BINARY_0_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_BINARY_NUM_PROPERTIES
};
static GParamSpec* gitg_diff_view_file_renderer_binary_properties[GITG_DIFF_VIEW_FILE_RENDERER_BINARY_NUM_PROPERTIES];

struct _GitgDiffViewFileRendererIface {
	GTypeInterface parent_iface;
	void (*add_hunk) (GitgDiffViewFileRenderer* self, GgitDiffHunk* hunk, GeeArrayList* lines);
};

struct _GitgDiffViewFileRendererBinary {
	GtkGrid parent_instance;
	GitgDiffViewFileRendererBinaryPrivate * priv;
};

struct _GitgDiffViewFileRendererBinaryClass {
	GtkGridClass parent_class;
};

static gpointer gitg_diff_view_file_renderer_binary_parent_class = NULL;
static GitgDiffViewFileRendererIface * gitg_diff_view_file_renderer_binary_gitg_diff_view_file_renderer_parent_iface = NULL;

VALA_EXTERN GType gitg_diff_view_file_renderer_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType gitg_diff_view_file_renderer_binary_get_type (void) G_GNUC_CONST ;
static void gitg_diff_view_file_renderer_binary_real_add_hunk (GitgDiffViewFileRenderer* base,
                                                        GgitDiffHunk* hunk,
                                                        GeeArrayList* lines);
VALA_EXTERN GitgDiffViewFileRendererBinary* gitg_diff_view_file_renderer_binary_new (void);
VALA_EXTERN GitgDiffViewFileRendererBinary* gitg_diff_view_file_renderer_binary_construct (GType object_type);
VALA_EXTERN void gitg_diff_view_file_renderer_add_hunk (GitgDiffViewFileRenderer* self,
                                            GgitDiffHunk* hunk,
                                            GeeArrayList* lines);
static GType gitg_diff_view_file_renderer_binary_get_type_once (void);

static void
gitg_diff_view_file_renderer_binary_real_add_hunk (GitgDiffViewFileRenderer* base,
                                                   GgitDiffHunk* hunk,
                                                   GeeArrayList* lines)
{
	GitgDiffViewFileRendererBinary * self;
	self = (GitgDiffViewFileRendererBinary*) base;
	g_return_if_fail (hunk != NULL);
	g_return_if_fail (lines != NULL);
}

GitgDiffViewFileRendererBinary*
gitg_diff_view_file_renderer_binary_construct (GType object_type)
{
	GitgDiffViewFileRendererBinary * self = NULL;
	self = (GitgDiffViewFileRendererBinary*) g_object_new (object_type, NULL);
	return self;
}

GitgDiffViewFileRendererBinary*
gitg_diff_view_file_renderer_binary_new (void)
{
	return gitg_diff_view_file_renderer_binary_construct (GITG_TYPE_DIFF_VIEW_FILE_RENDERER_BINARY);
}

static void
gitg_diff_view_file_renderer_binary_class_init (GitgDiffViewFileRendererBinaryClass * klass,
                                                gpointer klass_data)
{
	gitg_diff_view_file_renderer_binary_parent_class = g_type_class_peek_parent (klass);
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/gitg/ui/gitg-diff-view-file-renderer-binary.ui");
}

static void
gitg_diff_view_file_renderer_binary_gitg_diff_view_file_renderer_interface_init (GitgDiffViewFileRendererIface * iface,
                                                                                 gpointer iface_data)
{
	gitg_diff_view_file_renderer_binary_gitg_diff_view_file_renderer_parent_iface = g_type_interface_peek_parent (iface);
	iface->add_hunk = (void (*) (GitgDiffViewFileRenderer*, GgitDiffHunk*, GeeArrayList*)) gitg_diff_view_file_renderer_binary_real_add_hunk;
}

static void
gitg_diff_view_file_renderer_binary_instance_init (GitgDiffViewFileRendererBinary * self,
                                                   gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

 G_GNUC_NO_INLINE static GType
gitg_diff_view_file_renderer_binary_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgDiffViewFileRendererBinaryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_diff_view_file_renderer_binary_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgDiffViewFileRendererBinary), 0, (GInstanceInitFunc) gitg_diff_view_file_renderer_binary_instance_init, NULL };
	static const GInterfaceInfo gitg_diff_view_file_renderer_info = { (GInterfaceInitFunc) gitg_diff_view_file_renderer_binary_gitg_diff_view_file_renderer_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gitg_diff_view_file_renderer_binary_type_id;
	gitg_diff_view_file_renderer_binary_type_id = g_type_register_static (gtk_grid_get_type (), "GitgDiffViewFileRendererBinary", &g_define_type_info, 0);
	g_type_add_interface_static (gitg_diff_view_file_renderer_binary_type_id, GITG_TYPE_DIFF_VIEW_FILE_RENDERER, &gitg_diff_view_file_renderer_info);
	return gitg_diff_view_file_renderer_binary_type_id;
}

GType
gitg_diff_view_file_renderer_binary_get_type (void)
{
	static gsize gitg_diff_view_file_renderer_binary_type_id__once = 0;
	if (g_once_init_enter (&gitg_diff_view_file_renderer_binary_type_id__once)) {
		GType gitg_diff_view_file_renderer_binary_type_id;
		gitg_diff_view_file_renderer_binary_type_id = gitg_diff_view_file_renderer_binary_get_type_once ();
		g_once_init_leave (&gitg_diff_view_file_renderer_binary_type_id__once, gitg_diff_view_file_renderer_binary_type_id);
	}
	return gitg_diff_view_file_renderer_binary_type_id__once;
}

