/* gitg-builder.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-builder.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2015 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gee.h>
#include "libgitg-ext.h"
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_TYPE_BUILDER (gitg_builder_get_type ())
#define GITG_BUILDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_BUILDER, GitgBuilder))
#define GITG_BUILDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_BUILDER, GitgBuilderClass))
#define GITG_IS_BUILDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_BUILDER))
#define GITG_IS_BUILDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_BUILDER))
#define GITG_BUILDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_BUILDER, GitgBuilderClass))

typedef struct _GitgBuilder GitgBuilder;
typedef struct _GitgBuilderClass GitgBuilderClass;
typedef struct _GitgBuilderPrivate GitgBuilderPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _GitgParamSpecBuilder GitgParamSpecBuilder;

struct _GitgBuilder {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GitgBuilderPrivate * priv;
};

struct _GitgBuilderClass {
	GTypeClass parent_class;
	void (*finalize) (GitgBuilder *self);
};

struct _GitgParamSpecBuilder {
	GParamSpec parent_instance;
};

static gpointer gitg_builder_parent_class = NULL;

VALA_EXTERN gpointer gitg_builder_ref (gpointer instance);
VALA_EXTERN void gitg_builder_unref (gpointer instance);
VALA_EXTERN GParamSpec* gitg_param_spec_builder (const gchar* name,
                                     const gchar* nick,
                                     const gchar* blurb,
                                     GType object_type,
                                     GParamFlags flags);
VALA_EXTERN void gitg_value_set_builder (GValue* value,
                             gpointer v_object);
VALA_EXTERN void gitg_value_take_builder (GValue* value,
                              gpointer v_object);
VALA_EXTERN gpointer gitg_value_get_builder (const GValue* value);
VALA_EXTERN GType gitg_builder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgBuilder, gitg_builder_unref)
VALA_EXTERN gpointer gitg_builder_load_object (GType t_type,
                                   GBoxedCopyFunc t_dup_func,
                                   GDestroyNotify t_destroy_func,
                                   const gchar* id,
                                   const gchar* object);
VALA_EXTERN GitgBuilder* gitg_builder_new (void);
VALA_EXTERN GitgBuilder* gitg_builder_construct (GType object_type);
static void gitg_builder_finalize (GitgBuilder * obj);
static GType gitg_builder_get_type_once (void);

gpointer
gitg_builder_load_object (GType t_type,
                          GBoxedCopyFunc t_dup_func,
                          GDestroyNotify t_destroy_func,
                          const gchar* id,
                          const gchar* object)
{
	GeeHashMap* ret = NULL;
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
	GeeHashMap* _tmp2_;
	gpointer _tmp3_;
	gpointer result;
	g_return_val_if_fail (id != NULL, NULL);
	g_return_val_if_fail (object != NULL, NULL);
	_tmp0_ = gitg_ext_ui_from_builder (id, object, NULL);
	ret = _tmp0_;
	_tmp1_ = ret;
	if (_tmp1_ == NULL) {
		result = NULL;
		_g_object_unref0 (ret);
		return result;
	}
	_tmp2_ = ret;
	_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp2_, object);
	result = (gpointer) ((GObject*) _tmp3_);
	_g_object_unref0 (ret);
	return result;
}

GitgBuilder*
gitg_builder_construct (GType object_type)
{
	GitgBuilder* self = NULL;
	self = (GitgBuilder*) g_type_create_instance (object_type);
	return self;
}

GitgBuilder*
gitg_builder_new (void)
{
	return gitg_builder_construct (GITG_TYPE_BUILDER);
}

static void
gitg_value_builder_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
gitg_value_builder_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		gitg_builder_unref (value->data[0].v_pointer);
	}
}

static void
gitg_value_builder_copy_value (const GValue* src_value,
                               GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = gitg_builder_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
gitg_value_builder_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
gitg_value_builder_collect_value (GValue* value,
                                  guint n_collect_values,
                                  GTypeCValue* collect_values,
                                  guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		GitgBuilder * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = gitg_builder_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
gitg_value_builder_lcopy_value (const GValue* value,
                                guint n_collect_values,
                                GTypeCValue* collect_values,
                                guint collect_flags)
{
	GitgBuilder ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = gitg_builder_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
gitg_param_spec_builder (const gchar* name,
                         const gchar* nick,
                         const gchar* blurb,
                         GType object_type,
                         GParamFlags flags)
{
	GitgParamSpecBuilder* spec;
	g_return_val_if_fail (g_type_is_a (object_type, GITG_TYPE_BUILDER), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
gitg_value_get_builder (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GITG_TYPE_BUILDER), NULL);
	return value->data[0].v_pointer;
}

void
gitg_value_set_builder (GValue* value,
                        gpointer v_object)
{
	GitgBuilder * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GITG_TYPE_BUILDER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GITG_TYPE_BUILDER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		gitg_builder_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gitg_builder_unref (old);
	}
}

void
gitg_value_take_builder (GValue* value,
                         gpointer v_object)
{
	GitgBuilder * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GITG_TYPE_BUILDER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GITG_TYPE_BUILDER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gitg_builder_unref (old);
	}
}

static void
gitg_builder_class_init (GitgBuilderClass * klass,
                         gpointer klass_data)
{
	gitg_builder_parent_class = g_type_class_peek_parent (klass);
	((GitgBuilderClass *) klass)->finalize = gitg_builder_finalize;
}

static void
gitg_builder_instance_init (GitgBuilder * self,
                            gpointer klass)
{
	self->ref_count = 1;
}

static void
gitg_builder_finalize (GitgBuilder * obj)
{
	GitgBuilder * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_BUILDER, GitgBuilder);
	g_signal_handlers_destroy (self);
}

 G_GNUC_NO_INLINE static GType
gitg_builder_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { gitg_value_builder_init, gitg_value_builder_free_value, gitg_value_builder_copy_value, gitg_value_builder_peek_pointer, "p", gitg_value_builder_collect_value, "p", gitg_value_builder_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (GitgBuilderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_builder_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgBuilder), 0, (GInstanceInitFunc) gitg_builder_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType gitg_builder_type_id;
	gitg_builder_type_id = g_type_register_fundamental (g_type_fundamental_next (), "GitgBuilder", &g_define_type_info, &g_define_type_fundamental_info, 0);
	return gitg_builder_type_id;
}

GType
gitg_builder_get_type (void)
{
	static gsize gitg_builder_type_id__once = 0;
	if (g_once_init_enter (&gitg_builder_type_id__once)) {
		GType gitg_builder_type_id;
		gitg_builder_type_id = gitg_builder_get_type_once ();
		g_once_init_leave (&gitg_builder_type_id__once, gitg_builder_type_id);
	}
	return gitg_builder_type_id__once;
}

gpointer
gitg_builder_ref (gpointer instance)
{
	GitgBuilder * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
gitg_builder_unref (gpointer instance)
{
	GitgBuilder * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		GITG_BUILDER_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

