/* gitg.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2012 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "config.h"
#include <glib-object.h>
#include <gtk/gtk.h>
#include <locale.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <gobject/gvaluecollector.h>

#define GITG_version VERSION
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_TYPE_MAIN (gitg_main_get_type ())
#define GITG_MAIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_MAIN, GitgMain))
#define GITG_MAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_MAIN, GitgMainClass))
#define GITG_IS_MAIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_MAIN))
#define GITG_IS_MAIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_MAIN))
#define GITG_MAIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_MAIN, GitgMainClass))

typedef struct _GitgMain GitgMain;
typedef struct _GitgMainClass GitgMainClass;
typedef struct _GitgMainPrivate GitgMainPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define GITG_TYPE_APPLICATION (gitg_application_get_type ())
#define GITG_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_APPLICATION, GitgApplication))
#define GITG_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_APPLICATION, GitgApplicationClass))
#define GITG_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_APPLICATION))
#define GITG_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_APPLICATION))
#define GITG_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_APPLICATION, GitgApplicationClass))

typedef struct _GitgApplication GitgApplication;
typedef struct _GitgApplicationClass GitgApplicationClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _GitgParamSpecMain GitgParamSpecMain;

struct _GitgMain {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GitgMainPrivate * priv;
};

struct _GitgMainClass {
	GTypeClass parent_class;
	void (*finalize) (GitgMain *self);
};

struct _GitgParamSpecMain {
	GParamSpec parent_instance;
};

static gpointer gitg_main_parent_class = NULL;

VALA_EXTERN gpointer gitg_main_ref (gpointer instance);
VALA_EXTERN void gitg_main_unref (gpointer instance);
VALA_EXTERN GParamSpec* gitg_param_spec_main (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
VALA_EXTERN void gitg_value_set_main (GValue* value,
                          gpointer v_object);
VALA_EXTERN void gitg_value_take_main (GValue* value,
                           gpointer v_object);
VALA_EXTERN gpointer gitg_value_get_main (const GValue* value);
VALA_EXTERN GType gitg_main_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgMain, gitg_main_unref)
static gint gitg_main_main (gchar** args,
                     gint args_length1);
VALA_EXTERN gchar* gitg_dirs_get_locale_dir (void);
VALA_EXTERN GType gitg_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgApplication, g_object_unref)
VALA_EXTERN GitgApplication* gitg_application_new (void);
VALA_EXTERN GitgApplication* gitg_application_construct (GType object_type);
VALA_EXTERN GitgMain* gitg_main_new (void);
VALA_EXTERN GitgMain* gitg_main_construct (GType object_type);
static void gitg_main_finalize (GitgMain * obj);
static GType gitg_main_get_type_once (void);

static gint
gitg_main_main (gchar** args,
                gint args_length1)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GitgApplication* app = NULL;
	GitgApplication* _tmp3_;
	gint result;
	gtk_disable_setlocale ();
	setlocale (LC_ALL, "");
	setlocale (LC_COLLATE, "C");
	_tmp0_ = gitg_dirs_get_locale_dir ();
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	bindtextdomain (GETTEXT_PACKAGE, _tmp2_);
	_g_free0 (_tmp2_);
	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
	textdomain (GETTEXT_PACKAGE);
	g_set_prgname (APPLICATION_ID);
	g_set_application_name (_ ("gitg"));
	gtk_window_set_default_icon_name (APPLICATION_ID);
	_tmp3_ = gitg_application_new ();
	app = _tmp3_;
	result = g_application_run ((GApplication*) app, (gint) args_length1, args);
	_g_object_unref0 (app);
	return result;
}

int
main (int argc,
      char ** argv)
{
	return gitg_main_main (argv, argc);
}

GitgMain*
gitg_main_construct (GType object_type)
{
	GitgMain* self = NULL;
	self = (GitgMain*) g_type_create_instance (object_type);
	return self;
}

GitgMain*
gitg_main_new (void)
{
	return gitg_main_construct (GITG_TYPE_MAIN);
}

static void
gitg_value_main_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
gitg_value_main_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		gitg_main_unref (value->data[0].v_pointer);
	}
}

static void
gitg_value_main_copy_value (const GValue* src_value,
                            GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = gitg_main_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
gitg_value_main_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
gitg_value_main_collect_value (GValue* value,
                               guint n_collect_values,
                               GTypeCValue* collect_values,
                               guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		GitgMain * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = gitg_main_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
gitg_value_main_lcopy_value (const GValue* value,
                             guint n_collect_values,
                             GTypeCValue* collect_values,
                             guint collect_flags)
{
	GitgMain ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = gitg_main_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
gitg_param_spec_main (const gchar* name,
                      const gchar* nick,
                      const gchar* blurb,
                      GType object_type,
                      GParamFlags flags)
{
	GitgParamSpecMain* spec;
	g_return_val_if_fail (g_type_is_a (object_type, GITG_TYPE_MAIN), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
gitg_value_get_main (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GITG_TYPE_MAIN), NULL);
	return value->data[0].v_pointer;
}

void
gitg_value_set_main (GValue* value,
                     gpointer v_object)
{
	GitgMain * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GITG_TYPE_MAIN));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GITG_TYPE_MAIN));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		gitg_main_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gitg_main_unref (old);
	}
}

void
gitg_value_take_main (GValue* value,
                      gpointer v_object)
{
	GitgMain * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, GITG_TYPE_MAIN));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, GITG_TYPE_MAIN));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		gitg_main_unref (old);
	}
}

static void
gitg_main_class_init (GitgMainClass * klass,
                      gpointer klass_data)
{
	gitg_main_parent_class = g_type_class_peek_parent (klass);
	((GitgMainClass *) klass)->finalize = gitg_main_finalize;
}

static void
gitg_main_instance_init (GitgMain * self,
                         gpointer klass)
{
	self->ref_count = 1;
}

static void
gitg_main_finalize (GitgMain * obj)
{
	GitgMain * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_MAIN, GitgMain);
	g_signal_handlers_destroy (self);
}

 G_GNUC_NO_INLINE static GType
gitg_main_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { gitg_value_main_init, gitg_value_main_free_value, gitg_value_main_copy_value, gitg_value_main_peek_pointer, "p", gitg_value_main_collect_value, "p", gitg_value_main_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (GitgMainClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_main_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgMain), 0, (GInstanceInitFunc) gitg_main_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType gitg_main_type_id;
	gitg_main_type_id = g_type_register_fundamental (g_type_fundamental_next (), "GitgMain", &g_define_type_info, &g_define_type_fundamental_info, 0);
	return gitg_main_type_id;
}

GType
gitg_main_get_type (void)
{
	static gsize gitg_main_type_id__once = 0;
	if (g_once_init_enter (&gitg_main_type_id__once)) {
		GType gitg_main_type_id;
		gitg_main_type_id = gitg_main_get_type_once ();
		g_once_init_leave (&gitg_main_type_id__once, gitg_main_type_id);
	}
	return gitg_main_type_id__once;
}

gpointer
gitg_main_ref (gpointer instance)
{
	GitgMain * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
gitg_main_unref (gpointer instance)
{
	GitgMain * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		GITG_MAIN_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

