/* gitg-ref-action-delete.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-ref-action-delete.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2014 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib-object.h>
#include "libgitg-ext.h"
#include "libgitg.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "config.h"
#include <libgit2-glib/ggit.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>

#define GITG_REF_ACTION_DELETE_version VERSION
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_TYPE_REF_ACTION_DELETE (gitg_ref_action_delete_get_type ())
#define GITG_REF_ACTION_DELETE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_REF_ACTION_DELETE, GitgRefActionDelete))
#define GITG_REF_ACTION_DELETE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_REF_ACTION_DELETE, GitgRefActionDeleteClass))
#define GITG_IS_REF_ACTION_DELETE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_REF_ACTION_DELETE))
#define GITG_IS_REF_ACTION_DELETE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_REF_ACTION_DELETE))
#define GITG_REF_ACTION_DELETE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_REF_ACTION_DELETE, GitgRefActionDeleteClass))

typedef struct _GitgRefActionDelete GitgRefActionDelete;
typedef struct _GitgRefActionDeleteClass GitgRefActionDeleteClass;
typedef struct _GitgRefActionDeletePrivate GitgRefActionDeletePrivate;
enum  {
	GITG_REF_ACTION_DELETE_0_PROPERTY,
	GITG_REF_ACTION_DELETE_APPLICATION_PROPERTY,
	GITG_REF_ACTION_DELETE_ACTION_INTERFACE_PROPERTY,
	GITG_REF_ACTION_DELETE_REFERENCE_PROPERTY,
	GITG_REF_ACTION_DELETE_ID_PROPERTY,
	GITG_REF_ACTION_DELETE_DISPLAY_NAME_PROPERTY,
	GITG_REF_ACTION_DELETE_DESCRIPTION_PROPERTY,
	GITG_REF_ACTION_DELETE_ENABLED_PROPERTY,
	GITG_REF_ACTION_DELETE_NUM_PROPERTIES
};
static GParamSpec* gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

struct _GitgRefActionDelete {
	GObject parent_instance;
	GitgRefActionDeletePrivate * priv;
};

struct _GitgRefActionDeleteClass {
	GObjectClass parent_class;
};

struct _GitgRefActionDeletePrivate {
	GitgExtApplication* _application;
	GitgExtRefActionInterface* _action_interface;
	GitgRef* _reference;
};

static gint GitgRefActionDelete_private_offset;
static gpointer gitg_ref_action_delete_parent_class = NULL;
static GitgExtUIElementIface * gitg_ref_action_delete_gitg_ext_ui_element_parent_iface = NULL;
static GitgExtActionIface * gitg_ref_action_delete_gitg_ext_action_parent_iface = NULL;
static GitgExtRefActionIface * gitg_ref_action_delete_gitg_ext_ref_action_parent_iface = NULL;

VALA_EXTERN GType gitg_ref_action_delete_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgRefActionDelete, g_object_unref)
VALA_EXTERN GitgRefActionDelete* gitg_ref_action_delete_new (GitgExtApplication* application,
                                                 GitgExtRefActionInterface* action_interface,
                                                 GitgRef* reference);
VALA_EXTERN GitgRefActionDelete* gitg_ref_action_delete_construct (GType object_type,
                                                       GitgExtApplication* application,
                                                       GitgExtRefActionInterface* action_interface,
                                                       GitgRef* reference);
static void gitg_ref_action_delete_real_activate (GitgExtUIElement* base);
static gboolean gitg_ref_action_delete_on_response (GitgRefActionDelete* self,
                                             GtkResponseType response);
static gboolean _gitg_ref_action_delete_on_response_gitg_ext_user_query_response (GitgExtUserQuery* _sender,
                                                                           GtkResponseType response_type,
                                                                           gpointer self);
static void gitg_ref_action_delete_finalize (GObject * obj);
static GType gitg_ref_action_delete_get_type_once (void);
static void _vala_gitg_ref_action_delete_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec);
static void _vala_gitg_ref_action_delete_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
gitg_ref_action_delete_get_instance_private (GitgRefActionDelete* self)
{
	return G_STRUCT_MEMBER_P (self, GitgRefActionDelete_private_offset);
}

GitgRefActionDelete*
gitg_ref_action_delete_construct (GType object_type,
                                  GitgExtApplication* application,
                                  GitgExtRefActionInterface* action_interface,
                                  GitgRef* reference)
{
	GitgRefActionDelete * self = NULL;
	g_return_val_if_fail (application != NULL, NULL);
	g_return_val_if_fail (action_interface != NULL, NULL);
	g_return_val_if_fail (reference != NULL, NULL);
	self = (GitgRefActionDelete*) g_object_new (object_type, "application", application, "action-interface", action_interface, "reference", reference, NULL);
	return self;
}

GitgRefActionDelete*
gitg_ref_action_delete_new (GitgExtApplication* application,
                            GitgExtRefActionInterface* action_interface,
                            GitgRef* reference)
{
	return gitg_ref_action_delete_construct (GITG_TYPE_REF_ACTION_DELETE, application, action_interface, reference);
}

static gboolean
_gitg_ref_action_delete_on_response_gitg_ext_user_query_response (GitgExtUserQuery* _sender,
                                                                  GtkResponseType response_type,
                                                                  gpointer self)
{
	gboolean result;
	result = gitg_ref_action_delete_on_response ((GitgRefActionDelete*) self, response_type);
	return result;
}

static void
gitg_ref_action_delete_real_activate (GitgExtUIElement* base)
{
	GitgRefActionDelete * self;
	GitgExtUserQuery* query = NULL;
	GitgExtUserQuery* _tmp0_;
	gchar* name = NULL;
	GitgRef* _tmp1_;
	GitgRef* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	GitgRef* _tmp5_;
	GitgRef* _tmp6_;
	GitgExtUserQuery* _tmp33_;
	GitgExtUserQueryResponse* _tmp34_;
	GitgExtUserQueryResponse* _tmp35_;
	GitgExtUserQueryResponse** _tmp36_;
	GitgExtUserQueryResponse** _tmp37_;
	gint _tmp37__length1;
	GitgExtUserQuery* _tmp38_;
	GitgExtUserQuery* _tmp39_;
	GitgExtRefActionInterface* _tmp40_;
	GitgExtRefActionInterface* _tmp41_;
	GitgExtApplication* _tmp42_;
	GitgExtApplication* _tmp43_;
	GitgExtApplication* _tmp44_;
	GitgExtUserQuery* _tmp45_;
	self = (GitgRefActionDelete*) base;
	_tmp0_ = gitg_ext_user_query_new ();
	query = _tmp0_;
	_tmp1_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = ggit_ref_get_shorthand ((GgitRef*) _tmp2_);
	_tmp4_ = g_strdup (_tmp3_);
	name = _tmp4_;
	_tmp5_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
	_tmp6_ = _tmp5_;
	if (ggit_ref_is_branch ((GgitRef*) _tmp6_)) {
		GitgExtUserQuery* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		GitgExtUserQuery* _tmp11_;
		const gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		_tmp7_ = query;
		_tmp8_ = name;
		_tmp9_ = g_strdup_printf (_ ("Delete branch %s"), _tmp8_);
		_tmp10_ = _tmp9_;
		gitg_ext_user_query_set_title (_tmp7_, _tmp10_);
		_g_free0 (_tmp10_);
		_tmp11_ = query;
		_tmp12_ = name;
		_tmp13_ = g_strdup_printf (_ ("Are you sure that you want to permanently delete the branch %s?"), _tmp12_);
		_tmp14_ = _tmp13_;
		gitg_ext_user_query_set_message (_tmp11_, _tmp14_);
		_g_free0 (_tmp14_);
	} else {
		GitgRef* _tmp15_;
		GitgRef* _tmp16_;
		_tmp15_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
		_tmp16_ = _tmp15_;
		if (ggit_ref_is_tag ((GgitRef*) _tmp16_)) {
			GitgExtUserQuery* _tmp17_;
			const gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
			GitgExtUserQuery* _tmp21_;
			const gchar* _tmp22_;
			gchar* _tmp23_;
			gchar* _tmp24_;
			_tmp17_ = query;
			_tmp18_ = name;
			_tmp19_ = g_strdup_printf (_ ("Delete tag %s"), _tmp18_);
			_tmp20_ = _tmp19_;
			gitg_ext_user_query_set_title (_tmp17_, _tmp20_);
			_g_free0 (_tmp20_);
			_tmp21_ = query;
			_tmp22_ = name;
			_tmp23_ = g_strdup_printf (_ ("Are you sure that you want to permanently delete the tag %s?"), _tmp22_);
			_tmp24_ = _tmp23_;
			gitg_ext_user_query_set_message (_tmp21_, _tmp24_);
			_g_free0 (_tmp24_);
		} else {
			GitgExtUserQuery* _tmp25_;
			const gchar* _tmp26_;
			gchar* _tmp27_;
			gchar* _tmp28_;
			GitgExtUserQuery* _tmp29_;
			const gchar* _tmp30_;
			gchar* _tmp31_;
			gchar* _tmp32_;
			_tmp25_ = query;
			_tmp26_ = name;
			_tmp27_ = g_strdup_printf (_ ("Delete remote branch %s"), _tmp26_);
			_tmp28_ = _tmp27_;
			gitg_ext_user_query_set_title (_tmp25_, _tmp28_);
			_g_free0 (_tmp28_);
			_tmp29_ = query;
			_tmp30_ = name;
			_tmp31_ = g_strdup_printf (_ ("Are you sure that you want to permanently delete the remote branch %s?"), _tmp30_);
			_tmp32_ = _tmp31_;
			gitg_ext_user_query_set_message (_tmp29_, _tmp32_);
			_g_free0 (_tmp32_);
		}
	}
	_tmp33_ = query;
	_tmp34_ = gitg_ext_user_query_response_new (_ ("Cancel"), GTK_RESPONSE_CANCEL);
	_tmp35_ = gitg_ext_user_query_response_new (_ ("Delete"), GTK_RESPONSE_OK);
	_tmp36_ = g_new0 (GitgExtUserQueryResponse*, 2 + 1);
	_tmp36_[0] = _tmp34_;
	_tmp36_[1] = _tmp35_;
	_tmp37_ = _tmp36_;
	_tmp37__length1 = 2;
	gitg_ext_user_query_set_responses (_tmp33_, _tmp37_, (gint) 2);
	_tmp37_ = (_vala_array_free (_tmp37_, _tmp37__length1, (GDestroyNotify) g_object_unref), NULL);
	_tmp38_ = query;
	gitg_ext_user_query_set_default_response (_tmp38_, GTK_RESPONSE_OK);
	_tmp39_ = query;
	g_signal_connect_object (_tmp39_, "response", (GCallback) _gitg_ref_action_delete_on_response_gitg_ext_user_query_response, self, 0);
	_tmp40_ = gitg_ext_ref_action_get_action_interface ((GitgExtRefAction*) self);
	_tmp41_ = _tmp40_;
	_tmp42_ = gitg_ext_ref_action_interface_get_application (_tmp41_);
	_tmp43_ = _tmp42_;
	_tmp44_ = _tmp43_;
	_tmp45_ = query;
	gitg_ext_application_user_query (_tmp44_, _tmp45_);
	_g_object_unref0 (_tmp44_);
	_g_free0 (name);
	_g_object_unref0 (query);
}

static gboolean
gitg_ref_action_delete_on_response (GitgRefActionDelete* self,
                                    GtkResponseType response)
{
	GitgExtRefActionInterface* _tmp28_;
	GitgExtRefActionInterface* _tmp29_;
	GitgRef* _tmp30_;
	GitgRef* _tmp31_;
	GError* _inner_error0_ = NULL;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	if (response != GTK_RESPONSE_OK) {
		result = TRUE;
		return result;
	}
	{
		GitgRef* _tmp0_;
		GitgRef* _tmp1_;
		_tmp0_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
		_tmp1_ = _tmp0_;
		ggit_ref_delete ((GgitRef*) _tmp1_, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		gchar* title = NULL;
		gchar* message = NULL;
		gchar* name = NULL;
		GitgRef* _tmp2_;
		GitgRef* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		GitgRef* _tmp6_;
		GitgRef* _tmp7_;
		GitgExtRefActionInterface* _tmp20_;
		GitgExtRefActionInterface* _tmp21_;
		GitgExtApplication* _tmp22_;
		GitgExtApplication* _tmp23_;
		GitgExtApplication* _tmp24_;
		const gchar* _tmp25_;
		const gchar* _tmp26_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp2_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
		_tmp3_ = _tmp2_;
		_tmp4_ = ggit_ref_get_shorthand ((GgitRef*) _tmp3_);
		_tmp5_ = g_strdup (_tmp4_);
		name = _tmp5_;
		_tmp6_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
		_tmp7_ = _tmp6_;
		if (ggit_ref_is_tag ((GgitRef*) _tmp7_)) {
			const gchar* _tmp8_;
			gchar* _tmp9_;
			const gchar* _tmp10_;
			GError* _tmp11_;
			const gchar* _tmp12_;
			gchar* _tmp13_;
			_tmp8_ = name;
			_tmp9_ = g_strdup_printf (_ ("Failed to delete tag %s"), _tmp8_);
			_g_free0 (title);
			title = _tmp9_;
			_tmp10_ = name;
			_tmp11_ = e;
			_tmp12_ = _tmp11_->message;
			_tmp13_ = g_strdup_printf (_ ("The tag %s could not be deleted: %s"), _tmp10_, _tmp12_);
			_g_free0 (message);
			message = _tmp13_;
		} else {
			const gchar* _tmp14_;
			gchar* _tmp15_;
			const gchar* _tmp16_;
			GError* _tmp17_;
			const gchar* _tmp18_;
			gchar* _tmp19_;
			_tmp14_ = name;
			_tmp15_ = g_strdup_printf (_ ("Failed to delete branch %s"), _tmp14_);
			_g_free0 (title);
			title = _tmp15_;
			_tmp16_ = name;
			_tmp17_ = e;
			_tmp18_ = _tmp17_->message;
			_tmp19_ = g_strdup_printf (_ ("The branch %s could not be deleted: %s"), _tmp16_, _tmp18_);
			_g_free0 (message);
			message = _tmp19_;
		}
		_tmp20_ = gitg_ext_ref_action_get_action_interface ((GitgExtRefAction*) self);
		_tmp21_ = _tmp20_;
		_tmp22_ = gitg_ext_ref_action_interface_get_application (_tmp21_);
		_tmp23_ = _tmp22_;
		_tmp24_ = _tmp23_;
		_tmp25_ = title;
		_tmp26_ = message;
		gitg_ext_application_show_infobar (_tmp24_, _tmp25_, _tmp26_, GTK_MESSAGE_ERROR);
		_g_object_unref0 (_tmp24_);
		result = TRUE;
		_g_free0 (name);
		_g_free0 (message);
		_g_free0 (title);
		_g_error_free0 (e);
		return result;
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		gboolean _tmp27_ = FALSE;
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return _tmp27_;
	}
	_tmp28_ = gitg_ext_ref_action_get_action_interface ((GitgExtRefAction*) self);
	_tmp29_ = _tmp28_;
	_tmp30_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
	_tmp31_ = _tmp30_;
	gitg_ext_ref_action_interface_remove_ref (_tmp29_, _tmp31_);
	result = TRUE;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static GitgExtApplication*
gitg_ref_action_delete_real_get_application (GitgExtUIElement* base)
{
	GitgExtApplication* result;
	GitgRefActionDelete* self;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	self = (GitgRefActionDelete*) base;
	_tmp0_ = self->priv->_application;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}

static void
gitg_ref_action_delete_real_set_application (GitgExtUIElement* base,
                                             GitgExtApplication* value)
{
	GitgRefActionDelete* self;
	GitgExtApplication* old_value;
	self = (GitgRefActionDelete*) base;
	old_value = gitg_ref_action_delete_real_get_application (base);
	if (old_value != value) {
		GitgExtApplication* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_application);
		self->priv->_application = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_APPLICATION_PROPERTY]);
	}
	_g_object_unref0 (old_value);
}

static GitgExtRefActionInterface*
gitg_ref_action_delete_real_get_action_interface (GitgExtRefAction* base)
{
	GitgExtRefActionInterface* result;
	GitgRefActionDelete* self;
	GitgExtRefActionInterface* _tmp0_;
	self = (GitgRefActionDelete*) base;
	_tmp0_ = self->priv->_action_interface;
	result = _tmp0_;
	return result;
}

static void
gitg_ref_action_delete_real_set_action_interface (GitgExtRefAction* base,
                                                  GitgExtRefActionInterface* value)
{
	GitgRefActionDelete* self;
	GitgExtRefActionInterface* old_value;
	self = (GitgRefActionDelete*) base;
	old_value = gitg_ref_action_delete_real_get_action_interface (base);
	if (old_value != value) {
		GitgExtRefActionInterface* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_action_interface);
		self->priv->_action_interface = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_ACTION_INTERFACE_PROPERTY]);
	}
}

static GitgRef*
gitg_ref_action_delete_real_get_reference (GitgExtRefAction* base)
{
	GitgRef* result;
	GitgRefActionDelete* self;
	GitgRef* _tmp0_;
	self = (GitgRefActionDelete*) base;
	_tmp0_ = self->priv->_reference;
	result = _tmp0_;
	return result;
}

static void
gitg_ref_action_delete_real_set_reference (GitgExtRefAction* base,
                                           GitgRef* value)
{
	GitgRefActionDelete* self;
	GitgRef* old_value;
	self = (GitgRefActionDelete*) base;
	old_value = gitg_ref_action_delete_real_get_reference (base);
	if (old_value != value) {
		GitgRef* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_reference);
		self->priv->_reference = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_REFERENCE_PROPERTY]);
	}
}

static gchar*
gitg_ref_action_delete_real_get_id (GitgExtUIElement* base)
{
	gchar* result;
	GitgRefActionDelete* self;
	gchar* _tmp0_;
	self = (GitgRefActionDelete*) base;
	_tmp0_ = g_strdup ("/org/gnome/gitg/ref-actions/delete");
	result = _tmp0_;
	return result;
}

static gchar*
gitg_ref_action_delete_real_get_display_name (GitgExtUIElement* base)
{
	gchar* result;
	GitgRefActionDelete* self;
	gchar* _tmp0_;
	self = (GitgRefActionDelete*) base;
	_tmp0_ = g_strdup (_ ("Delete"));
	result = _tmp0_;
	return result;
}

static gchar*
gitg_ref_action_delete_real_get_description (GitgExtUIElement* base)
{
	gchar* result;
	GitgRefActionDelete* self;
	gchar* _tmp0_;
	self = (GitgRefActionDelete*) base;
	_tmp0_ = g_strdup (_ ("Delete the selected reference"));
	result = _tmp0_;
	return result;
}

static gboolean
gitg_ref_action_delete_real_get_enabled (GitgExtUIElement* base)
{
	gboolean result;
	GitgRefActionDelete* self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GitgRef* _tmp2_;
	GitgRef* _tmp3_;
	GError* _inner_error0_ = NULL;
	self = (GitgRefActionDelete*) base;
	_tmp2_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
	_tmp3_ = _tmp2_;
	if (ggit_ref_is_branch ((GgitRef*) _tmp3_)) {
		gboolean _tmp4_ = FALSE;
		GitgRef* _tmp5_;
		GitgRef* _tmp6_;
		_tmp5_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
		_tmp6_ = _tmp5_;
		_tmp4_ = ggit_branch_is_head (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, ggit_branch_get_type (), GgitBranch), &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			gboolean _tmp7_ = FALSE;
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return _tmp7_;
		}
		_tmp1_ = !_tmp4_;
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		_tmp0_ = TRUE;
	} else {
		GitgRef* _tmp8_;
		GitgRef* _tmp9_;
		_tmp8_ = gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self);
		_tmp9_ = _tmp8_;
		_tmp0_ = ggit_ref_is_tag ((GgitRef*) _tmp9_);
	}
	result = _tmp0_;
	return result;
}

static void
gitg_ref_action_delete_class_init (GitgRefActionDeleteClass * klass,
                                   gpointer klass_data)
{
	gitg_ref_action_delete_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgRefActionDelete_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gitg_ref_action_delete_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gitg_ref_action_delete_set_property;
	G_OBJECT_CLASS (klass)->finalize = gitg_ref_action_delete_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_DELETE_APPLICATION_PROPERTY, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_APPLICATION_PROPERTY] = g_param_spec_object ("application", "application", "application", GITG_EXT_TYPE_APPLICATION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_DELETE_ACTION_INTERFACE_PROPERTY, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_ACTION_INTERFACE_PROPERTY] = g_param_spec_object ("action-interface", "action-interface", "action-interface", GITG_EXT_TYPE_REF_ACTION_INTERFACE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_DELETE_REFERENCE_PROPERTY, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_REFERENCE_PROPERTY] = g_param_spec_object ("reference", "reference", "reference", GITG_TYPE_REF, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_DELETE_ID_PROPERTY, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_DELETE_DISPLAY_NAME_PROPERTY, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_DISPLAY_NAME_PROPERTY] = g_param_spec_string ("display-name", "display-name", "display-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_DELETE_DESCRIPTION_PROPERTY, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_DESCRIPTION_PROPERTY] = g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_REF_ACTION_DELETE_ENABLED_PROPERTY, gitg_ref_action_delete_properties[GITG_REF_ACTION_DELETE_ENABLED_PROPERTY] = g_param_spec_boolean ("enabled", "enabled", "enabled", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
gitg_ref_action_delete_gitg_ext_ui_element_interface_init (GitgExtUIElementIface * iface,
                                                           gpointer iface_data)
{
	gitg_ref_action_delete_gitg_ext_ui_element_parent_iface = g_type_interface_peek_parent (iface);
	iface->activate = (void (*) (GitgExtUIElement*)) gitg_ref_action_delete_real_activate;
	iface->get_application = gitg_ref_action_delete_real_get_application;
	iface->set_application = gitg_ref_action_delete_real_set_application;
	iface->get_id = gitg_ref_action_delete_real_get_id;
	iface->get_display_name = gitg_ref_action_delete_real_get_display_name;
	iface->get_description = gitg_ref_action_delete_real_get_description;
	iface->get_enabled = gitg_ref_action_delete_real_get_enabled;
}

static void
gitg_ref_action_delete_gitg_ext_action_interface_init (GitgExtActionIface * iface,
                                                       gpointer iface_data)
{
	gitg_ref_action_delete_gitg_ext_action_parent_iface = g_type_interface_peek_parent (iface);
}

static void
gitg_ref_action_delete_gitg_ext_ref_action_interface_init (GitgExtRefActionIface * iface,
                                                           gpointer iface_data)
{
	gitg_ref_action_delete_gitg_ext_ref_action_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_action_interface = gitg_ref_action_delete_real_get_action_interface;
	iface->set_action_interface = gitg_ref_action_delete_real_set_action_interface;
	iface->get_reference = gitg_ref_action_delete_real_get_reference;
	iface->set_reference = gitg_ref_action_delete_real_set_reference;
}

static void
gitg_ref_action_delete_instance_init (GitgRefActionDelete * self,
                                      gpointer klass)
{
	self->priv = gitg_ref_action_delete_get_instance_private (self);
}

static void
gitg_ref_action_delete_finalize (GObject * obj)
{
	GitgRefActionDelete * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_REF_ACTION_DELETE, GitgRefActionDelete);
	_g_object_unref0 (self->priv->_application);
	_g_object_unref0 (self->priv->_action_interface);
	_g_object_unref0 (self->priv->_reference);
	G_OBJECT_CLASS (gitg_ref_action_delete_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_ref_action_delete_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgRefActionDeleteClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_ref_action_delete_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgRefActionDelete), 0, (GInstanceInitFunc) gitg_ref_action_delete_instance_init, NULL };
	static const GInterfaceInfo gitg_ext_ui_element_info = { (GInterfaceInitFunc) gitg_ref_action_delete_gitg_ext_ui_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_ext_action_info = { (GInterfaceInitFunc) gitg_ref_action_delete_gitg_ext_action_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_ext_ref_action_info = { (GInterfaceInitFunc) gitg_ref_action_delete_gitg_ext_ref_action_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gitg_ref_action_delete_type_id;
	gitg_ref_action_delete_type_id = g_type_register_static (G_TYPE_OBJECT, "GitgRefActionDelete", &g_define_type_info, 0);
	g_type_add_interface_static (gitg_ref_action_delete_type_id, GITG_EXT_TYPE_UI_ELEMENT, &gitg_ext_ui_element_info);
	g_type_add_interface_static (gitg_ref_action_delete_type_id, GITG_EXT_TYPE_ACTION, &gitg_ext_action_info);
	g_type_add_interface_static (gitg_ref_action_delete_type_id, GITG_EXT_TYPE_REF_ACTION, &gitg_ext_ref_action_info);
	GitgRefActionDelete_private_offset = g_type_add_instance_private (gitg_ref_action_delete_type_id, sizeof (GitgRefActionDeletePrivate));
	return gitg_ref_action_delete_type_id;
}

GType
gitg_ref_action_delete_get_type (void)
{
	static gsize gitg_ref_action_delete_type_id__once = 0;
	if (g_once_init_enter (&gitg_ref_action_delete_type_id__once)) {
		GType gitg_ref_action_delete_type_id;
		gitg_ref_action_delete_type_id = gitg_ref_action_delete_get_type_once ();
		g_once_init_leave (&gitg_ref_action_delete_type_id__once, gitg_ref_action_delete_type_id);
	}
	return gitg_ref_action_delete_type_id__once;
}

static void
_vala_gitg_ref_action_delete_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec)
{
	GitgRefActionDelete * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_REF_ACTION_DELETE, GitgRefActionDelete);
	switch (property_id) {
		case GITG_REF_ACTION_DELETE_APPLICATION_PROPERTY:
		g_value_take_object (value, gitg_ext_ui_element_get_application ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_DELETE_ACTION_INTERFACE_PROPERTY:
		g_value_set_object (value, gitg_ext_ref_action_get_action_interface ((GitgExtRefAction*) self));
		break;
		case GITG_REF_ACTION_DELETE_REFERENCE_PROPERTY:
		g_value_set_object (value, gitg_ext_ref_action_get_reference ((GitgExtRefAction*) self));
		break;
		case GITG_REF_ACTION_DELETE_ID_PROPERTY:
		g_value_take_string (value, gitg_ext_ui_element_get_id ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_DELETE_DISPLAY_NAME_PROPERTY:
		g_value_take_string (value, gitg_ext_ui_element_get_display_name ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_DELETE_DESCRIPTION_PROPERTY:
		g_value_take_string (value, gitg_ext_ui_element_get_description ((GitgExtUIElement*) self));
		break;
		case GITG_REF_ACTION_DELETE_ENABLED_PROPERTY:
		g_value_set_boolean (value, gitg_ext_ui_element_get_enabled ((GitgExtUIElement*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gitg_ref_action_delete_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec)
{
	GitgRefActionDelete * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_REF_ACTION_DELETE, GitgRefActionDelete);
	switch (property_id) {
		case GITG_REF_ACTION_DELETE_APPLICATION_PROPERTY:
		gitg_ext_ui_element_set_application ((GitgExtUIElement*) self, g_value_get_object (value));
		break;
		case GITG_REF_ACTION_DELETE_ACTION_INTERFACE_PROPERTY:
		gitg_ext_ref_action_set_action_interface ((GitgExtRefAction*) self, g_value_get_object (value));
		break;
		case GITG_REF_ACTION_DELETE_REFERENCE_PROPERTY:
		gitg_ext_ref_action_set_reference ((GitgExtRefAction*) self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

