/* gitg-history-action-interface.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-history-action-interface.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2014 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib-object.h>
#include "libgitg-ext.h"
#include <gtk/gtk.h>
#include <glib.h>
#include "libgitg.h"
#include <gee.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_HISTORY_TYPE_ACTION_INTERFACE (gitg_history_action_interface_get_type ())
#define GITG_HISTORY_ACTION_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_HISTORY_TYPE_ACTION_INTERFACE, GitgHistoryActionInterface))
#define GITG_HISTORY_ACTION_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_HISTORY_TYPE_ACTION_INTERFACE, GitgHistoryActionInterfaceClass))
#define GITG_HISTORY_IS_ACTION_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_HISTORY_TYPE_ACTION_INTERFACE))
#define GITG_HISTORY_IS_ACTION_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_HISTORY_TYPE_ACTION_INTERFACE))
#define GITG_HISTORY_ACTION_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_HISTORY_TYPE_ACTION_INTERFACE, GitgHistoryActionInterfaceClass))

typedef struct _GitgHistoryActionInterface GitgHistoryActionInterface;
typedef struct _GitgHistoryActionInterfaceClass GitgHistoryActionInterfaceClass;
typedef struct _GitgHistoryActionInterfacePrivate GitgHistoryActionInterfacePrivate;

#define GITG_HISTORY_TYPE_REFS_LIST (gitg_history_refs_list_get_type ())
#define GITG_HISTORY_REFS_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_HISTORY_TYPE_REFS_LIST, GitgHistoryRefsList))
#define GITG_HISTORY_REFS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_HISTORY_TYPE_REFS_LIST, GitgHistoryRefsListClass))
#define GITG_HISTORY_IS_REFS_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_HISTORY_TYPE_REFS_LIST))
#define GITG_HISTORY_IS_REFS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_HISTORY_TYPE_REFS_LIST))
#define GITG_HISTORY_REFS_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_HISTORY_TYPE_REFS_LIST, GitgHistoryRefsListClass))

typedef struct _GitgHistoryRefsList GitgHistoryRefsList;
typedef struct _GitgHistoryRefsListClass GitgHistoryRefsListClass;
enum  {
	GITG_HISTORY_ACTION_INTERFACE_0_PROPERTY,
	GITG_HISTORY_ACTION_INTERFACE_APPLICATION_PROPERTY,
	GITG_HISTORY_ACTION_INTERFACE_REFERENCES_PROPERTY,
	GITG_HISTORY_ACTION_INTERFACE_NUM_PROPERTIES
};
static GParamSpec* gitg_history_action_interface_properties[GITG_HISTORY_ACTION_INTERFACE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
enum  {
	GITG_HISTORY_ACTION_INTERFACE_UPDATED_SIGNAL,
	GITG_HISTORY_ACTION_INTERFACE_NUM_SIGNALS
};
static guint gitg_history_action_interface_signals[GITG_HISTORY_ACTION_INTERFACE_NUM_SIGNALS] = {0};

struct _GitgHistoryActionInterface {
	GObject parent_instance;
	GitgHistoryActionInterfacePrivate * priv;
};

struct _GitgHistoryActionInterfaceClass {
	GObjectClass parent_class;
};

struct _GitgHistoryActionInterfacePrivate {
	GitgExtApplication* _application;
	GitgHistoryRefsList* d_refs_list;
};

static gint GitgHistoryActionInterface_private_offset;
static gpointer gitg_history_action_interface_parent_class = NULL;
static GitgExtRefActionInterfaceIface * gitg_history_action_interface_gitg_ext_ref_action_interface_parent_iface = NULL;

VALA_EXTERN GType gitg_history_action_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgHistoryActionInterface, g_object_unref)
VALA_EXTERN GType gitg_history_refs_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgHistoryRefsList, g_object_unref)
VALA_EXTERN GitgHistoryActionInterface* gitg_history_action_interface_new (GitgExtApplication* application,
                                                               GitgHistoryRefsList* refs_list);
VALA_EXTERN GitgHistoryActionInterface* gitg_history_action_interface_construct (GType object_type,
                                                                     GitgExtApplication* application,
                                                                     GitgHistoryRefsList* refs_list);
static void gitg_history_action_interface_real_add_ref (GitgExtRefActionInterface* base,
                                                 GitgRef* reference);
VALA_EXTERN gboolean gitg_history_refs_list_add_ref (GitgHistoryRefsList* self,
                                         GitgRef* reference);
static void gitg_history_action_interface_real_remove_ref (GitgExtRefActionInterface* base,
                                                    GitgRef* reference);
VALA_EXTERN gboolean gitg_history_refs_list_remove_ref (GitgHistoryRefsList* self,
                                            GitgRef* reference);
static void gitg_history_action_interface_real_replace_ref (GitgExtRefActionInterface* base,
                                                     GitgRef* old_ref,
                                                     GitgRef* new_ref);
VALA_EXTERN void gitg_history_refs_list_replace_ref (GitgHistoryRefsList* self,
                                         GitgRef* old_ref,
                                         GitgRef* new_ref);
static void gitg_history_action_interface_real_set_busy (GitgExtRefActionInterface* base,
                                                  GitgRef* reference,
                                                  gboolean busy);
static void gitg_history_action_interface_real_edit_ref_name (GitgExtRefActionInterface* base,
                                                       GitgRef* reference,
                                                       GitgExtRefNameEditingDone done,
                                                       gpointer done_target,
                                                       GDestroyNotify done_target_destroy_notify);
VALA_EXTERN void gitg_history_refs_list_edit (GitgHistoryRefsList* self,
                                  GitgRef* reference,
                                  GitgExtRefNameEditingDone done,
                                  gpointer done_target,
                                  GDestroyNotify done_target_destroy_notify);
static void gitg_history_action_interface_real_refresh (GitgExtRefActionInterface* base);
VALA_EXTERN void gitg_history_refs_list_set_repository (GitgHistoryRefsList* self,
                                            GitgRepository* value);
VALA_EXTERN GeeList* gitg_history_refs_list_get_references (GitgHistoryRefsList* self);
static void gitg_history_action_interface_finalize (GObject * obj);
static GType gitg_history_action_interface_get_type_once (void);
static void _vala_gitg_history_action_interface_get_property (GObject * object,
                                                       guint property_id,
                                                       GValue * value,
                                                       GParamSpec * pspec);
static void _vala_gitg_history_action_interface_set_property (GObject * object,
                                                       guint property_id,
                                                       const GValue * value,
                                                       GParamSpec * pspec);

static inline gpointer
gitg_history_action_interface_get_instance_private (GitgHistoryActionInterface* self)
{
	return G_STRUCT_MEMBER_P (self, GitgHistoryActionInterface_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

GitgHistoryActionInterface*
gitg_history_action_interface_construct (GType object_type,
                                         GitgExtApplication* application,
                                         GitgHistoryRefsList* refs_list)
{
	GitgHistoryActionInterface * self = NULL;
	GitgHistoryRefsList* _tmp0_;
	g_return_val_if_fail (application != NULL, NULL);
	g_return_val_if_fail (refs_list != NULL, NULL);
	self = (GitgHistoryActionInterface*) g_object_new (object_type, "application", application, NULL);
	_tmp0_ = _g_object_ref0 (refs_list);
	_g_object_unref0 (self->priv->d_refs_list);
	self->priv->d_refs_list = _tmp0_;
	return self;
}

GitgHistoryActionInterface*
gitg_history_action_interface_new (GitgExtApplication* application,
                                   GitgHistoryRefsList* refs_list)
{
	return gitg_history_action_interface_construct (GITG_HISTORY_TYPE_ACTION_INTERFACE, application, refs_list);
}

static void
gitg_history_action_interface_real_add_ref (GitgExtRefActionInterface* base,
                                            GitgRef* reference)
{
	GitgHistoryActionInterface * self;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	GitgExtApplication* _tmp2_;
	GitgRepository* _tmp3_;
	GitgRepository* _tmp4_;
	GitgRepository* _tmp5_;
	GitgHistoryRefsList* _tmp6_;
	self = (GitgHistoryActionInterface*) base;
	g_return_if_fail (reference != NULL);
	_tmp0_ = gitg_ext_ref_action_interface_get_application ((GitgExtRefActionInterface*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gitg_ext_application_get_repository (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	gitg_repository_clear_refs_cache (_tmp5_);
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (_tmp2_);
	_tmp6_ = self->priv->d_refs_list;
	gitg_history_refs_list_add_ref (_tmp6_, reference);
	g_signal_emit (self, gitg_history_action_interface_signals[GITG_HISTORY_ACTION_INTERFACE_UPDATED_SIGNAL], 0);
}

static void
gitg_history_action_interface_real_remove_ref (GitgExtRefActionInterface* base,
                                               GitgRef* reference)
{
	GitgHistoryActionInterface * self;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	GitgExtApplication* _tmp2_;
	GitgRepository* _tmp3_;
	GitgRepository* _tmp4_;
	GitgRepository* _tmp5_;
	GitgHistoryRefsList* _tmp6_;
	self = (GitgHistoryActionInterface*) base;
	g_return_if_fail (reference != NULL);
	_tmp0_ = gitg_ext_ref_action_interface_get_application ((GitgExtRefActionInterface*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gitg_ext_application_get_repository (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	gitg_repository_clear_refs_cache (_tmp5_);
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (_tmp2_);
	_tmp6_ = self->priv->d_refs_list;
	gitg_history_refs_list_remove_ref (_tmp6_, reference);
	g_signal_emit (self, gitg_history_action_interface_signals[GITG_HISTORY_ACTION_INTERFACE_UPDATED_SIGNAL], 0);
}

static void
gitg_history_action_interface_real_replace_ref (GitgExtRefActionInterface* base,
                                                GitgRef* old_ref,
                                                GitgRef* new_ref)
{
	GitgHistoryActionInterface * self;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	GitgExtApplication* _tmp2_;
	GitgRepository* _tmp3_;
	GitgRepository* _tmp4_;
	GitgRepository* _tmp5_;
	GitgHistoryRefsList* _tmp6_;
	self = (GitgHistoryActionInterface*) base;
	g_return_if_fail (old_ref != NULL);
	g_return_if_fail (new_ref != NULL);
	_tmp0_ = gitg_ext_ref_action_interface_get_application ((GitgExtRefActionInterface*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gitg_ext_application_get_repository (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	gitg_repository_clear_refs_cache (_tmp5_);
	_g_object_unref0 (_tmp5_);
	_g_object_unref0 (_tmp2_);
	_tmp6_ = self->priv->d_refs_list;
	gitg_history_refs_list_replace_ref (_tmp6_, old_ref, new_ref);
	g_signal_emit (self, gitg_history_action_interface_signals[GITG_HISTORY_ACTION_INTERFACE_UPDATED_SIGNAL], 0);
}

static void
gitg_history_action_interface_real_set_busy (GitgExtRefActionInterface* base,
                                             GitgRef* reference,
                                             gboolean busy)
{
	GitgHistoryActionInterface * self;
	self = (GitgHistoryActionInterface*) base;
	g_return_if_fail (reference != NULL);
}

static void
gitg_history_action_interface_real_edit_ref_name (GitgExtRefActionInterface* base,
                                                  GitgRef* reference,
                                                  GitgExtRefNameEditingDone done,
                                                  gpointer done_target,
                                                  GDestroyNotify done_target_destroy_notify)
{
	GitgHistoryActionInterface * self;
	GitgHistoryRefsList* _tmp0_;
	GitgExtRefNameEditingDone _tmp1_;
	gpointer _tmp1__target;
	GDestroyNotify _tmp1__target_destroy_notify;
	self = (GitgHistoryActionInterface*) base;
	g_return_if_fail (reference != NULL);
	_tmp0_ = self->priv->d_refs_list;
	_tmp1_ = done;
	_tmp1__target = done_target;
	_tmp1__target_destroy_notify = done_target_destroy_notify;
	done = NULL;
	done_target = NULL;
	done_target_destroy_notify = NULL;
	gitg_history_refs_list_edit (_tmp0_, reference, _tmp1_, _tmp1__target, _tmp1__target_destroy_notify);
	(done_target_destroy_notify == NULL) ? NULL : (done_target_destroy_notify (done_target), NULL);
	done = NULL;
	done_target = NULL;
	done_target_destroy_notify = NULL;
}

static void
gitg_history_action_interface_real_refresh (GitgExtRefActionInterface* base)
{
	GitgHistoryActionInterface * self;
	GitgHistoryRefsList* _tmp0_;
	GitgExtApplication* _tmp1_;
	GitgExtApplication* _tmp2_;
	GitgExtApplication* _tmp3_;
	GitgRepository* _tmp4_;
	GitgRepository* _tmp5_;
	GitgRepository* _tmp6_;
	self = (GitgHistoryActionInterface*) base;
	_tmp0_ = self->priv->d_refs_list;
	_tmp1_ = gitg_ext_ref_action_interface_get_application ((GitgExtRefActionInterface*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = gitg_ext_application_get_repository (_tmp3_);
	_tmp5_ = _tmp4_;
	_tmp6_ = _tmp5_;
	gitg_history_refs_list_set_repository (_tmp0_, _tmp6_);
	_g_object_unref0 (_tmp6_);
	_g_object_unref0 (_tmp3_);
	g_signal_emit (self, gitg_history_action_interface_signals[GITG_HISTORY_ACTION_INTERFACE_UPDATED_SIGNAL], 0);
}

static GitgExtApplication*
gitg_history_action_interface_real_get_application (GitgExtRefActionInterface* base)
{
	GitgExtApplication* result;
	GitgHistoryActionInterface* self;
	GitgExtApplication* _tmp0_;
	GitgExtApplication* _tmp1_;
	self = (GitgHistoryActionInterface*) base;
	_tmp0_ = self->priv->_application;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	result = _tmp1_;
	return result;
}

static void
gitg_history_action_interface_real_set_application (GitgExtRefActionInterface* base,
                                                    GitgExtApplication* value)
{
	GitgHistoryActionInterface* self;
	GitgExtApplication* old_value;
	self = (GitgHistoryActionInterface*) base;
	old_value = gitg_history_action_interface_real_get_application (base);
	if (old_value != value) {
		GitgExtApplication* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_application);
		self->priv->_application = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_history_action_interface_properties[GITG_HISTORY_ACTION_INTERFACE_APPLICATION_PROPERTY]);
	}
	_g_object_unref0 (old_value);
}

static GeeList*
gitg_history_action_interface_real_get_references (GitgExtRefActionInterface* base)
{
	GeeList* result;
	GitgHistoryActionInterface* self;
	GitgHistoryRefsList* _tmp0_;
	GeeList* _tmp1_;
	GeeList* _tmp2_;
	self = (GitgHistoryActionInterface*) base;
	_tmp0_ = self->priv->d_refs_list;
	_tmp1_ = gitg_history_refs_list_get_references (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

static void
gitg_history_action_interface_class_init (GitgHistoryActionInterfaceClass * klass,
                                          gpointer klass_data)
{
	gitg_history_action_interface_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgHistoryActionInterface_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gitg_history_action_interface_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gitg_history_action_interface_set_property;
	G_OBJECT_CLASS (klass)->finalize = gitg_history_action_interface_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_HISTORY_ACTION_INTERFACE_APPLICATION_PROPERTY, gitg_history_action_interface_properties[GITG_HISTORY_ACTION_INTERFACE_APPLICATION_PROPERTY] = g_param_spec_object ("application", "application", "application", GITG_EXT_TYPE_APPLICATION, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_HISTORY_ACTION_INTERFACE_REFERENCES_PROPERTY, gitg_history_action_interface_properties[GITG_HISTORY_ACTION_INTERFACE_REFERENCES_PROPERTY] = g_param_spec_object ("references", "references", "references", GEE_TYPE_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	gitg_history_action_interface_signals[GITG_HISTORY_ACTION_INTERFACE_UPDATED_SIGNAL] = g_signal_new ("updated", GITG_HISTORY_TYPE_ACTION_INTERFACE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static void
gitg_history_action_interface_gitg_ext_ref_action_interface_interface_init (GitgExtRefActionInterfaceIface * iface,
                                                                            gpointer iface_data)
{
	gitg_history_action_interface_gitg_ext_ref_action_interface_parent_iface = g_type_interface_peek_parent (iface);
	iface->add_ref = (void (*) (GitgExtRefActionInterface*, GitgRef*)) gitg_history_action_interface_real_add_ref;
	iface->remove_ref = (void (*) (GitgExtRefActionInterface*, GitgRef*)) gitg_history_action_interface_real_remove_ref;
	iface->replace_ref = (void (*) (GitgExtRefActionInterface*, GitgRef*, GitgRef*)) gitg_history_action_interface_real_replace_ref;
	iface->set_busy = (void (*) (GitgExtRefActionInterface*, GitgRef*, gboolean)) gitg_history_action_interface_real_set_busy;
	iface->edit_ref_name = (void (*) (GitgExtRefActionInterface*, GitgRef*, GitgExtRefNameEditingDone, gpointer, GDestroyNotify)) gitg_history_action_interface_real_edit_ref_name;
	iface->refresh = (void (*) (GitgExtRefActionInterface*)) gitg_history_action_interface_real_refresh;
	iface->get_application = gitg_history_action_interface_real_get_application;
	iface->set_application = gitg_history_action_interface_real_set_application;
	iface->get_references = gitg_history_action_interface_real_get_references;
}

static void
gitg_history_action_interface_instance_init (GitgHistoryActionInterface * self,
                                             gpointer klass)
{
	self->priv = gitg_history_action_interface_get_instance_private (self);
}

static void
gitg_history_action_interface_finalize (GObject * obj)
{
	GitgHistoryActionInterface * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_HISTORY_TYPE_ACTION_INTERFACE, GitgHistoryActionInterface);
	_g_object_unref0 (self->priv->_application);
	_g_object_unref0 (self->priv->d_refs_list);
	G_OBJECT_CLASS (gitg_history_action_interface_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_history_action_interface_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgHistoryActionInterfaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_history_action_interface_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgHistoryActionInterface), 0, (GInstanceInitFunc) gitg_history_action_interface_instance_init, NULL };
	static const GInterfaceInfo gitg_ext_ref_action_interface_info = { (GInterfaceInitFunc) gitg_history_action_interface_gitg_ext_ref_action_interface_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gitg_history_action_interface_type_id;
	gitg_history_action_interface_type_id = g_type_register_static (G_TYPE_OBJECT, "GitgHistoryActionInterface", &g_define_type_info, 0);
	g_type_add_interface_static (gitg_history_action_interface_type_id, GITG_EXT_TYPE_REF_ACTION_INTERFACE, &gitg_ext_ref_action_interface_info);
	GitgHistoryActionInterface_private_offset = g_type_add_instance_private (gitg_history_action_interface_type_id, sizeof (GitgHistoryActionInterfacePrivate));
	return gitg_history_action_interface_type_id;
}

GType
gitg_history_action_interface_get_type (void)
{
	static gsize gitg_history_action_interface_type_id__once = 0;
	if (g_once_init_enter (&gitg_history_action_interface_type_id__once)) {
		GType gitg_history_action_interface_type_id;
		gitg_history_action_interface_type_id = gitg_history_action_interface_get_type_once ();
		g_once_init_leave (&gitg_history_action_interface_type_id__once, gitg_history_action_interface_type_id);
	}
	return gitg_history_action_interface_type_id__once;
}

static void
_vala_gitg_history_action_interface_get_property (GObject * object,
                                                  guint property_id,
                                                  GValue * value,
                                                  GParamSpec * pspec)
{
	GitgHistoryActionInterface * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_HISTORY_TYPE_ACTION_INTERFACE, GitgHistoryActionInterface);
	switch (property_id) {
		case GITG_HISTORY_ACTION_INTERFACE_APPLICATION_PROPERTY:
		g_value_take_object (value, gitg_ext_ref_action_interface_get_application ((GitgExtRefActionInterface*) self));
		break;
		case GITG_HISTORY_ACTION_INTERFACE_REFERENCES_PROPERTY:
		g_value_take_object (value, gitg_ext_ref_action_interface_get_references ((GitgExtRefActionInterface*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gitg_history_action_interface_set_property (GObject * object,
                                                  guint property_id,
                                                  const GValue * value,
                                                  GParamSpec * pspec)
{
	GitgHistoryActionInterface * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_HISTORY_TYPE_ACTION_INTERFACE, GitgHistoryActionInterface);
	switch (property_id) {
		case GITG_HISTORY_ACTION_INTERFACE_APPLICATION_PROPERTY:
		gitg_ext_ref_action_interface_set_application ((GitgExtRefActionInterface*) self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

