/* diff.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __PLUGINS_DIFF_DIFF_H__
#define __PLUGINS_DIFF_DIFF_H__

#include <glib-object.h>
#include "libgitg-ext.h"
#include <glib.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_DIFF_TYPE_PANEL (gitg_diff_panel_get_type ())
#define GITG_DIFF_PANEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_DIFF_TYPE_PANEL, GitgDiffPanel))
#define GITG_DIFF_PANEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_DIFF_TYPE_PANEL, GitgDiffPanelClass))
#define GITG_DIFF_IS_PANEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_DIFF_TYPE_PANEL))
#define GITG_DIFF_IS_PANEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_DIFF_TYPE_PANEL))
#define GITG_DIFF_PANEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_DIFF_TYPE_PANEL, GitgDiffPanelClass))

typedef struct _GitgDiffPanel GitgDiffPanel;
typedef struct _GitgDiffPanelClass GitgDiffPanelClass;
typedef struct _GitgDiffPanelPrivate GitgDiffPanelPrivate;

struct _GitgDiffPanel {
	GObject parent_instance;
	GitgDiffPanelPrivate * priv;
};

struct _GitgDiffPanelClass {
	GObjectClass parent_class;
	guint* (*get_shortcut) (GitgDiffPanel* self);
};

GType gitg_diff_panel_register_type (GTypeModule * module);
VALA_EXTERN GType gitg_diff_panel_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgDiffPanel, g_object_unref)
VALA_EXTERN GitgDiffPanel* gitg_diff_panel_new (void);
VALA_EXTERN GitgDiffPanel* gitg_diff_panel_construct (GType object_type);
VALA_EXTERN guint* gitg_diff_panel_get_shortcut (GitgDiffPanel* self);
VALA_EXTERN void peas_register_types (GTypeModule* module);

G_END_DECLS

#endif
