/* gitg-ext-command-line.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-ext-command-line.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2012 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include "libgitg-ext.h"
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

static GType gitg_ext_command_line_get_type_once (void);

GOptionGroup*
gitg_ext_command_line_get_option_group (GitgExtCommandLine* self)
{
	GitgExtCommandLineIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = GITG_EXT_COMMAND_LINE_GET_INTERFACE (self);
	if (_iface_->get_option_group) {
		return _iface_->get_option_group (self);
	}
	return NULL;
}

void
gitg_ext_command_line_parse_finished (GitgExtCommandLine* self)
{
	GitgExtCommandLineIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = GITG_EXT_COMMAND_LINE_GET_INTERFACE (self);
	if (_iface_->parse_finished) {
		_iface_->parse_finished (self);
	}
}

void
gitg_ext_command_line_apply (GitgExtCommandLine* self,
                             GitgExtApplication* application)
{
	GitgExtCommandLineIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = GITG_EXT_COMMAND_LINE_GET_INTERFACE (self);
	if (_iface_->apply) {
		_iface_->apply (self, application);
	}
}

static void
gitg_ext_command_line_default_init (GitgExtCommandLineIface * iface,
                                    gpointer iface_data)
{
}

 G_GNUC_NO_INLINE static GType
gitg_ext_command_line_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgExtCommandLineIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_ext_command_line_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType gitg_ext_command_line_type_id;
	gitg_ext_command_line_type_id = g_type_register_static (G_TYPE_INTERFACE, "GitgExtCommandLine", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (gitg_ext_command_line_type_id, G_TYPE_OBJECT);
	return gitg_ext_command_line_type_id;
}

GType
gitg_ext_command_line_get_type (void)
{
	static gsize gitg_ext_command_line_type_id__once = 0;
	if (g_once_init_enter (&gitg_ext_command_line_type_id__once)) {
		GType gitg_ext_command_line_type_id;
		gitg_ext_command_line_type_id = gitg_ext_command_line_get_type_once ();
		g_once_init_leave (&gitg_ext_command_line_type_id__once, gitg_ext_command_line_type_id);
	}
	return gitg_ext_command_line_type_id__once;
}

