/* gitg-ext-commit-action.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-ext-commit-action.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2014 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include "libgitg-ext.h"
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	GITG_EXT_COMMIT_ACTION_FINISHED_SIGNAL,
	GITG_EXT_COMMIT_ACTION_NUM_SIGNALS
};
static guint gitg_ext_commit_action_signals[GITG_EXT_COMMIT_ACTION_NUM_SIGNALS] = {0};

static GType gitg_ext_commit_action_get_type_once (void);

GitgExtRefActionInterface*
gitg_ext_commit_action_get_action_interface (GitgExtCommitAction* self)
{
	GitgExtCommitActionIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = GITG_EXT_COMMIT_ACTION_GET_INTERFACE (self);
	if (_iface_->get_action_interface) {
		return _iface_->get_action_interface (self);
	}
	return NULL;
}

void
gitg_ext_commit_action_set_action_interface (GitgExtCommitAction* self,
                                             GitgExtRefActionInterface* value)
{
	GitgExtCommitActionIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = GITG_EXT_COMMIT_ACTION_GET_INTERFACE (self);
	if (_iface_->set_action_interface) {
		_iface_->set_action_interface (self, value);
	}
}

GitgCommit*
gitg_ext_commit_action_get_commit (GitgExtCommitAction* self)
{
	GitgExtCommitActionIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = GITG_EXT_COMMIT_ACTION_GET_INTERFACE (self);
	if (_iface_->get_commit) {
		return _iface_->get_commit (self);
	}
	return NULL;
}

void
gitg_ext_commit_action_set_commit (GitgExtCommitAction* self,
                                   GitgCommit* value)
{
	GitgExtCommitActionIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = GITG_EXT_COMMIT_ACTION_GET_INTERFACE (self);
	if (_iface_->set_commit) {
		_iface_->set_commit (self, value);
	}
}

static void
gitg_ext_commit_action_default_init (GitgExtCommitActionIface * iface,
                                     gpointer iface_data)
{
	g_object_interface_install_property (iface, g_param_spec_object ("action-interface", "action-interface", "action-interface", GITG_EXT_TYPE_REF_ACTION_INTERFACE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_interface_install_property (iface, g_param_spec_object ("commit", "commit", "commit", GITG_TYPE_COMMIT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	gitg_ext_commit_action_signals[GITG_EXT_COMMIT_ACTION_FINISHED_SIGNAL] = g_signal_new ("finished", GITG_EXT_TYPE_COMMIT_ACTION, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

 G_GNUC_NO_INLINE static GType
gitg_ext_commit_action_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgExtCommitActionIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_ext_commit_action_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType gitg_ext_commit_action_type_id;
	gitg_ext_commit_action_type_id = g_type_register_static (G_TYPE_INTERFACE, "GitgExtCommitAction", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (gitg_ext_commit_action_type_id, GITG_EXT_TYPE_ACTION);
	return gitg_ext_commit_action_type_id;
}

GType
gitg_ext_commit_action_get_type (void)
{
	static gsize gitg_ext_commit_action_type_id__once = 0;
	if (g_once_init_enter (&gitg_ext_commit_action_type_id__once)) {
		GType gitg_ext_commit_action_type_id;
		gitg_ext_commit_action_type_id = gitg_ext_commit_action_get_type_once ();
		g_once_init_leave (&gitg_ext_commit_action_type_id__once, gitg_ext_commit_action_type_id);
	}
	return gitg_ext_commit_action_type_id__once;
}

