/* gitg-commit-paned.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-commit-paned.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2012 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include "libgitg.h"
#include <glib.h>
#include <gio/gio.h>
#include "config.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_COMMIT_TYPE_PANED (gitg_commit_paned_get_type ())
#define GITG_COMMIT_PANED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_COMMIT_TYPE_PANED, GitgCommitPaned))
#define GITG_COMMIT_PANED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_COMMIT_TYPE_PANED, GitgCommitPanedClass))
#define GITG_COMMIT_IS_PANED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_COMMIT_TYPE_PANED))
#define GITG_COMMIT_IS_PANED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_COMMIT_TYPE_PANED))
#define GITG_COMMIT_PANED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_COMMIT_TYPE_PANED, GitgCommitPanedClass))

typedef struct _GitgCommitPaned GitgCommitPaned;
typedef struct _GitgCommitPanedClass GitgCommitPanedClass;
typedef struct _GitgCommitPanedPrivate GitgCommitPanedPrivate;

#define GITG_COMMIT_TYPE_SIDEBAR (gitg_commit_sidebar_get_type ())
#define GITG_COMMIT_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_COMMIT_TYPE_SIDEBAR, GitgCommitSidebar))
#define GITG_COMMIT_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_COMMIT_TYPE_SIDEBAR, GitgCommitSidebarClass))
#define GITG_COMMIT_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_COMMIT_TYPE_SIDEBAR))
#define GITG_COMMIT_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_COMMIT_TYPE_SIDEBAR))
#define GITG_COMMIT_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_COMMIT_TYPE_SIDEBAR, GitgCommitSidebarClass))

typedef struct _GitgCommitSidebar GitgCommitSidebar;
typedef struct _GitgCommitSidebarClass GitgCommitSidebarClass;

#define GITG_COMMIT_TYPE_SUBMODULE_HISTORY_VIEW (gitg_commit_submodule_history_view_get_type ())
#define GITG_COMMIT_SUBMODULE_HISTORY_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_COMMIT_TYPE_SUBMODULE_HISTORY_VIEW, GitgCommitSubmoduleHistoryView))
#define GITG_COMMIT_SUBMODULE_HISTORY_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_COMMIT_TYPE_SUBMODULE_HISTORY_VIEW, GitgCommitSubmoduleHistoryViewClass))
#define GITG_COMMIT_IS_SUBMODULE_HISTORY_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_COMMIT_TYPE_SUBMODULE_HISTORY_VIEW))
#define GITG_COMMIT_IS_SUBMODULE_HISTORY_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_COMMIT_TYPE_SUBMODULE_HISTORY_VIEW))
#define GITG_COMMIT_SUBMODULE_HISTORY_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_COMMIT_TYPE_SUBMODULE_HISTORY_VIEW, GitgCommitSubmoduleHistoryViewClass))

typedef struct _GitgCommitSubmoduleHistoryView GitgCommitSubmoduleHistoryView;
typedef struct _GitgCommitSubmoduleHistoryViewClass GitgCommitSubmoduleHistoryViewClass;

#define GITG_COMMIT_TYPE_SUBMODULE_DIFF_VIEW (gitg_commit_submodule_diff_view_get_type ())
#define GITG_COMMIT_SUBMODULE_DIFF_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_COMMIT_TYPE_SUBMODULE_DIFF_VIEW, GitgCommitSubmoduleDiffView))
#define GITG_COMMIT_SUBMODULE_DIFF_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_COMMIT_TYPE_SUBMODULE_DIFF_VIEW, GitgCommitSubmoduleDiffViewClass))
#define GITG_COMMIT_IS_SUBMODULE_DIFF_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_COMMIT_TYPE_SUBMODULE_DIFF_VIEW))
#define GITG_COMMIT_IS_SUBMODULE_DIFF_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_COMMIT_TYPE_SUBMODULE_DIFF_VIEW))
#define GITG_COMMIT_SUBMODULE_DIFF_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_COMMIT_TYPE_SUBMODULE_DIFF_VIEW, GitgCommitSubmoduleDiffViewClass))

typedef struct _GitgCommitSubmoduleDiffView GitgCommitSubmoduleDiffView;
typedef struct _GitgCommitSubmoduleDiffViewClass GitgCommitSubmoduleDiffViewClass;
enum  {
	GITG_COMMIT_PANED_0_PROPERTY,
	GITG_COMMIT_PANED_SIDEBAR_PROPERTY,
	GITG_COMMIT_PANED_DIFF_VIEW_PROPERTY,
	GITG_COMMIT_PANED_SUBMODULE_HISTORY_VIEW_PROPERTY,
	GITG_COMMIT_PANED_SUBMODULE_DIFF_VIEW_PROPERTY,
	GITG_COMMIT_PANED_SKIP_HOOKS_PROPERTY,
	GITG_COMMIT_PANED_BUTTON_COMMIT_PROPERTY,
	GITG_COMMIT_PANED_BUTTON_STAGE_PROPERTY,
	GITG_COMMIT_PANED_BUTTON_DISCARD_PROPERTY,
	GITG_COMMIT_PANED_COMMIT_FILES_SEARCH_BAR_PROPERTY,
	GITG_COMMIT_PANED_COMMIT_FILES_SEARCH_ENTRY_PROPERTY,
	GITG_COMMIT_PANED_NUM_PROPERTIES
};
static GParamSpec* gitg_commit_paned_properties[GITG_COMMIT_PANED_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _GitgCommitPaned {
	GtkPaned parent_instance;
	GitgCommitPanedPrivate * priv;
};

struct _GitgCommitPanedClass {
	GtkPanedClass parent_class;
};

struct _GitgCommitPanedPrivate {
	GitgCommitSidebar* d_tree_view_files;
	GitgDiffView* d_diff_view;
	GitgCommitSubmoduleHistoryView* d_submodule_history_view;
	GitgCommitSubmoduleDiffView* d_submodule_diff_view;
	GtkCheckButton* d_check_button_skip_hooks;
	GtkButton* d_button_commit;
	GtkButton* d_button_stage;
	GtkButton* d_button_discard;
	GtkSearchBar* d_files_search_bar;
	GtkSearchEntry* d_files_search_entry;
};

static gint GitgCommitPaned_private_offset;
static gpointer gitg_commit_paned_parent_class = NULL;

VALA_EXTERN GType gitg_commit_paned_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgCommitPaned, g_object_unref)
VALA_EXTERN GType gitg_commit_sidebar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgCommitSidebar, g_object_unref)
VALA_EXTERN GType gitg_commit_submodule_history_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgCommitSubmoduleHistoryView, g_object_unref)
VALA_EXTERN GType gitg_commit_submodule_diff_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgCommitSubmoduleDiffView, g_object_unref)
VALA_EXTERN GitgCommitPaned* gitg_commit_paned_new (void);
VALA_EXTERN GitgCommitPaned* gitg_commit_paned_construct (GType object_type);
VALA_EXTERN GitgCommitSidebar* gitg_commit_paned_get_sidebar (GitgCommitPaned* self);
VALA_EXTERN GitgDiffView* gitg_commit_paned_get_diff_view (GitgCommitPaned* self);
VALA_EXTERN GitgCommitSubmoduleHistoryView* gitg_commit_paned_get_submodule_history_view (GitgCommitPaned* self);
VALA_EXTERN GitgCommitSubmoduleDiffView* gitg_commit_paned_get_submodule_diff_view (GitgCommitPaned* self);
VALA_EXTERN gboolean gitg_commit_paned_get_skip_hooks (GitgCommitPaned* self);
VALA_EXTERN GtkButton* gitg_commit_paned_get_button_commit (GitgCommitPaned* self);
VALA_EXTERN GtkButton* gitg_commit_paned_get_button_stage (GitgCommitPaned* self);
VALA_EXTERN GtkButton* gitg_commit_paned_get_button_discard (GitgCommitPaned* self);
VALA_EXTERN GtkSearchBar* gitg_commit_paned_get_commit_files_search_bar (GitgCommitPaned* self);
VALA_EXTERN GtkSearchEntry* gitg_commit_paned_get_commit_files_search_entry (GitgCommitPaned* self);
static GObject * gitg_commit_paned_constructor (GType type,
                                         guint n_construct_properties,
                                         GObjectConstructParam * construct_properties);
static void gitg_commit_paned_finalize (GObject * obj);
static GType gitg_commit_paned_get_type_once (void);
static void _vala_gitg_commit_paned_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec);

static inline gpointer
gitg_commit_paned_get_instance_private (GitgCommitPaned* self)
{
	return G_STRUCT_MEMBER_P (self, GitgCommitPaned_private_offset);
}

GitgCommitPaned*
gitg_commit_paned_construct (GType object_type)
{
	GitgCommitPaned * self = NULL;
	self = (GitgCommitPaned*) g_object_new (object_type, "orientation", GTK_ORIENTATION_HORIZONTAL, NULL);
	return self;
}

GitgCommitPaned*
gitg_commit_paned_new (void)
{
	return gitg_commit_paned_construct (GITG_COMMIT_TYPE_PANED);
}

GitgCommitSidebar*
gitg_commit_paned_get_sidebar (GitgCommitPaned* self)
{
	GitgCommitSidebar* result;
	GitgCommitSidebar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_tree_view_files;
	result = _tmp0_;
	return result;
}

GitgDiffView*
gitg_commit_paned_get_diff_view (GitgCommitPaned* self)
{
	GitgDiffView* result;
	GitgDiffView* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_diff_view;
	result = _tmp0_;
	return result;
}

GitgCommitSubmoduleHistoryView*
gitg_commit_paned_get_submodule_history_view (GitgCommitPaned* self)
{
	GitgCommitSubmoduleHistoryView* result;
	GitgCommitSubmoduleHistoryView* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_submodule_history_view;
	result = _tmp0_;
	return result;
}

GitgCommitSubmoduleDiffView*
gitg_commit_paned_get_submodule_diff_view (GitgCommitPaned* self)
{
	GitgCommitSubmoduleDiffView* result;
	GitgCommitSubmoduleDiffView* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_submodule_diff_view;
	result = _tmp0_;
	return result;
}

gboolean
gitg_commit_paned_get_skip_hooks (GitgCommitPaned* self)
{
	gboolean result;
	GtkCheckButton* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->d_check_button_skip_hooks;
	_tmp1_ = gtk_toggle_button_get_active ((GtkToggleButton*) _tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

GtkButton*
gitg_commit_paned_get_button_commit (GitgCommitPaned* self)
{
	GtkButton* result;
	GtkButton* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_button_commit;
	result = _tmp0_;
	return result;
}

GtkButton*
gitg_commit_paned_get_button_stage (GitgCommitPaned* self)
{
	GtkButton* result;
	GtkButton* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_button_stage;
	result = _tmp0_;
	return result;
}

GtkButton*
gitg_commit_paned_get_button_discard (GitgCommitPaned* self)
{
	GtkButton* result;
	GtkButton* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_button_discard;
	result = _tmp0_;
	return result;
}

GtkSearchBar*
gitg_commit_paned_get_commit_files_search_bar (GitgCommitPaned* self)
{
	GtkSearchBar* result;
	GtkSearchBar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_files_search_bar;
	result = _tmp0_;
	return result;
}

GtkSearchEntry*
gitg_commit_paned_get_commit_files_search_entry (GitgCommitPaned* self)
{
	GtkSearchEntry* result;
	GtkSearchEntry* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_files_search_entry;
	result = _tmp0_;
	return result;
}

static GObject *
gitg_commit_paned_constructor (GType type,
                               guint n_construct_properties,
                               GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GitgCommitPaned * self;
	GSettings* state_settings = NULL;
	GSettings* _tmp0_;
	GSettings* _tmp1_;
	parent_class = G_OBJECT_CLASS (gitg_commit_paned_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_COMMIT_TYPE_PANED, GitgCommitPaned);
	_tmp0_ = g_settings_new (APPLICATION_ID ".state.commit");
	state_settings = _tmp0_;
	_tmp1_ = state_settings;
	g_settings_bind (_tmp1_, "paned-sidebar-position", (GObject*) self, "position", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
	_g_object_unref0 (state_settings);
	return obj;
}

static void
gitg_commit_paned_class_init (GitgCommitPanedClass * klass,
                              gpointer klass_data)
{
	gitg_commit_paned_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgCommitPaned_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gitg_commit_paned_get_property;
	G_OBJECT_CLASS (klass)->constructor = gitg_commit_paned_constructor;
	G_OBJECT_CLASS (klass)->finalize = gitg_commit_paned_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_SIDEBAR_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_SIDEBAR_PROPERTY] = g_param_spec_object ("sidebar", "sidebar", "sidebar", GITG_COMMIT_TYPE_SIDEBAR, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_DIFF_VIEW_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_DIFF_VIEW_PROPERTY] = g_param_spec_object ("diff-view", "diff-view", "diff-view", GITG_TYPE_DIFF_VIEW, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_SUBMODULE_HISTORY_VIEW_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_SUBMODULE_HISTORY_VIEW_PROPERTY] = g_param_spec_object ("submodule-history-view", "submodule-history-view", "submodule-history-view", GITG_COMMIT_TYPE_SUBMODULE_HISTORY_VIEW, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_SUBMODULE_DIFF_VIEW_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_SUBMODULE_DIFF_VIEW_PROPERTY] = g_param_spec_object ("submodule-diff-view", "submodule-diff-view", "submodule-diff-view", GITG_COMMIT_TYPE_SUBMODULE_DIFF_VIEW, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_SKIP_HOOKS_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_SKIP_HOOKS_PROPERTY] = g_param_spec_boolean ("skip-hooks", "skip-hooks", "skip-hooks", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_BUTTON_COMMIT_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_BUTTON_COMMIT_PROPERTY] = g_param_spec_object ("button-commit", "button-commit", "button-commit", gtk_button_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_BUTTON_STAGE_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_BUTTON_STAGE_PROPERTY] = g_param_spec_object ("button-stage", "button-stage", "button-stage", gtk_button_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_BUTTON_DISCARD_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_BUTTON_DISCARD_PROPERTY] = g_param_spec_object ("button-discard", "button-discard", "button-discard", gtk_button_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_COMMIT_FILES_SEARCH_BAR_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_COMMIT_FILES_SEARCH_BAR_PROPERTY] = g_param_spec_object ("commit-files-search-bar", "commit-files-search-bar", "commit-files-search-bar", gtk_search_bar_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_COMMIT_PANED_COMMIT_FILES_SEARCH_ENTRY_PROPERTY, gitg_commit_paned_properties[GITG_COMMIT_PANED_COMMIT_FILES_SEARCH_ENTRY_PROPERTY] = g_param_spec_object ("commit-files-search-entry", "commit-files-search-entry", "commit-files-search-entry", gtk_search_entry_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/gitg/ui/gitg-commit-paned.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "tree_view_files", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_tree_view_files));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "diff_view", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_diff_view));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "submodule_history_view", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_submodule_history_view));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "submodule_diff_view", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_submodule_diff_view));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "check_button_skip_hooks", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_check_button_skip_hooks));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "button_commit", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_button_commit));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "button_stage", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_button_stage));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "button_discard", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_button_discard));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "commit_files_search_bar", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_files_search_bar));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "commit_files_search_entry", FALSE, GitgCommitPaned_private_offset + G_STRUCT_OFFSET (GitgCommitPanedPrivate, d_files_search_entry));
}

static void
gitg_commit_paned_instance_init (GitgCommitPaned * self,
                                 gpointer klass)
{
	self->priv = gitg_commit_paned_get_instance_private (self);
	g_type_ensure (GITG_COMMIT_TYPE_SIDEBAR);
	g_type_ensure (GITG_COMMIT_TYPE_SUBMODULE_HISTORY_VIEW);
	g_type_ensure (GITG_COMMIT_TYPE_SUBMODULE_DIFF_VIEW);
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
gitg_commit_paned_finalize (GObject * obj)
{
	GitgCommitPaned * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_COMMIT_TYPE_PANED, GitgCommitPaned);
	G_OBJECT_CLASS (gitg_commit_paned_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_commit_paned_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgCommitPanedClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_commit_paned_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgCommitPaned), 0, (GInstanceInitFunc) gitg_commit_paned_instance_init, NULL };
	GType gitg_commit_paned_type_id;
	gitg_commit_paned_type_id = g_type_register_static (gtk_paned_get_type (), "GitgCommitPaned", &g_define_type_info, 0);
	GitgCommitPaned_private_offset = g_type_add_instance_private (gitg_commit_paned_type_id, sizeof (GitgCommitPanedPrivate));
	return gitg_commit_paned_type_id;
}

GType
gitg_commit_paned_get_type (void)
{
	static gsize gitg_commit_paned_type_id__once = 0;
	if (g_once_init_enter (&gitg_commit_paned_type_id__once)) {
		GType gitg_commit_paned_type_id;
		gitg_commit_paned_type_id = gitg_commit_paned_get_type_once ();
		g_once_init_leave (&gitg_commit_paned_type_id__once, gitg_commit_paned_type_id);
	}
	return gitg_commit_paned_type_id__once;
}

static void
_vala_gitg_commit_paned_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec)
{
	GitgCommitPaned * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_COMMIT_TYPE_PANED, GitgCommitPaned);
	switch (property_id) {
		case GITG_COMMIT_PANED_SIDEBAR_PROPERTY:
		g_value_set_object (value, gitg_commit_paned_get_sidebar (self));
		break;
		case GITG_COMMIT_PANED_DIFF_VIEW_PROPERTY:
		g_value_set_object (value, gitg_commit_paned_get_diff_view (self));
		break;
		case GITG_COMMIT_PANED_SUBMODULE_HISTORY_VIEW_PROPERTY:
		g_value_set_object (value, gitg_commit_paned_get_submodule_history_view (self));
		break;
		case GITG_COMMIT_PANED_SUBMODULE_DIFF_VIEW_PROPERTY:
		g_value_set_object (value, gitg_commit_paned_get_submodule_diff_view (self));
		break;
		case GITG_COMMIT_PANED_SKIP_HOOKS_PROPERTY:
		g_value_set_boolean (value, gitg_commit_paned_get_skip_hooks (self));
		break;
		case GITG_COMMIT_PANED_BUTTON_COMMIT_PROPERTY:
		g_value_set_object (value, gitg_commit_paned_get_button_commit (self));
		break;
		case GITG_COMMIT_PANED_BUTTON_STAGE_PROPERTY:
		g_value_set_object (value, gitg_commit_paned_get_button_stage (self));
		break;
		case GITG_COMMIT_PANED_BUTTON_DISCARD_PROPERTY:
		g_value_set_object (value, gitg_commit_paned_get_button_discard (self));
		break;
		case GITG_COMMIT_PANED_COMMIT_FILES_SEARCH_BAR_PROPERTY:
		g_value_set_object (value, gitg_commit_paned_get_commit_files_search_bar (self));
		break;
		case GITG_COMMIT_PANED_COMMIT_FILES_SEARCH_ENTRY_PROPERTY:
		g_value_set_object (value, gitg_commit_paned_get_commit_files_search_entry (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

