/* gitg-notifications.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-notifications.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2014 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib-object.h>
#include "libgitg-ext.h"
#include <gtk/gtk.h>
#include <gee.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_TYPE_NOTIFICATIONS (gitg_notifications_get_type ())
#define GITG_NOTIFICATIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_NOTIFICATIONS, GitgNotifications))
#define GITG_NOTIFICATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_NOTIFICATIONS, GitgNotificationsClass))
#define GITG_IS_NOTIFICATIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_NOTIFICATIONS))
#define GITG_IS_NOTIFICATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_NOTIFICATIONS))
#define GITG_NOTIFICATIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_NOTIFICATIONS, GitgNotificationsClass))

typedef struct _GitgNotifications GitgNotifications;
typedef struct _GitgNotificationsClass GitgNotificationsClass;
typedef struct _GitgNotificationsPrivate GitgNotificationsPrivate;
enum  {
	GITG_NOTIFICATIONS_0_PROPERTY,
	GITG_NOTIFICATIONS_NUM_PROPERTIES
};
static GParamSpec* gitg_notifications_properties[GITG_NOTIFICATIONS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block67Data Block67Data;
typedef struct _Block68Data Block68Data;
typedef struct _Block69Data Block69Data;

struct _GitgNotifications {
	GObject parent_instance;
	GitgNotificationsPrivate * priv;
};

struct _GitgNotificationsClass {
	GObjectClass parent_class;
};

struct _GitgNotificationsPrivate {
	GtkOverlay* d_overlay;
	GeeHashMap* d_delay_handles;
	GtkBox* d_box;
	GeeHashMap* d_handles;
};

struct _Block67Data {
	int _ref_count_;
	GitgNotifications* self;
	GitgExtNotification* notification;
};

struct _Block68Data {
	int _ref_count_;
	GitgNotifications* self;
	GtkRevealer* revealer;
	GitgExtNotification* notification;
};

struct _Block69Data {
	int _ref_count_;
	GitgNotifications* self;
	GitgExtNotification* notification;
};

static gint GitgNotifications_private_offset;
static gpointer gitg_notifications_parent_class = NULL;
static GitgExtNotificationsIface * gitg_notifications_gitg_ext_notifications_parent_iface = NULL;

VALA_EXTERN GType gitg_notifications_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgNotifications, g_object_unref)
VALA_EXTERN GitgNotifications* gitg_notifications_new (GtkOverlay* overlay);
VALA_EXTERN GitgNotifications* gitg_notifications_construct (GType object_type,
                                                 GtkOverlay* overlay);
static void gitg_notifications_real_dispose (GObject* base);
static void gitg_notifications_real_add (GitgExtNotifications* base,
                                  GitgExtNotification* notification);
static Block67Data* block67_data_ref (Block67Data* _data67_);
static void block67_data_unref (void * _userdata_);
static void __lambda174_ (Block67Data* _data67_,
                   guint delay);
static void ___lambda174__gitg_ext_notification_close (GitgExtNotification* _sender,
                                                guint delay,
                                                gpointer self);
static void gitg_notifications_remove_now (GitgNotifications* self,
                                    GitgExtNotification* notification);
static Block68Data* block68_data_ref (Block68Data* _data68_);
static void block68_data_unref (void * _userdata_);
static void __lambda176_ (Block68Data* _data68_);
static void ___lambda176__g_object_notify (GObject* _sender,
                                    GParamSpec* pspec,
                                    gpointer self);
static void gitg_notifications_real_remove (GitgExtNotifications* base,
                                     GitgExtNotification* notification,
                                     guint delay);
static Block69Data* block69_data_ref (Block69Data* _data69_);
static void block69_data_unref (void * _userdata_);
static gboolean __lambda175_ (Block69Data* _data69_);
static gboolean ___lambda175__gsource_func (gpointer self);
static void gitg_notifications_finalize (GObject * obj);
static GType gitg_notifications_get_type_once (void);

static inline gpointer
gitg_notifications_get_instance_private (GitgNotifications* self)
{
	return G_STRUCT_MEMBER_P (self, GitgNotifications_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

GitgNotifications*
gitg_notifications_construct (GType object_type,
                              GtkOverlay* overlay)
{
	GitgNotifications * self = NULL;
	GtkOverlay* _tmp0_;
	GeeHashMap* _tmp1_;
	GeeHashMap* _tmp2_;
	GtkBox* _tmp3_;
	GtkBox* _tmp4_;
	GtkStyleContext* _tmp5_;
	GtkBox* _tmp6_;
	GtkBox* _tmp7_;
	GtkOverlay* _tmp8_;
	GtkBox* _tmp9_;
	g_return_val_if_fail (overlay != NULL, NULL);
	self = (GitgNotifications*) g_object_new (object_type, NULL);
	_tmp0_ = _g_object_ref0 (overlay);
	_g_object_unref0 (self->priv->d_overlay);
	self->priv->d_overlay = _tmp0_;
	_tmp1_ = gee_hash_map_new (GITG_EXT_TYPE_NOTIFICATION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_UINT, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	_g_object_unref0 (self->priv->d_delay_handles);
	self->priv->d_delay_handles = _tmp1_;
	_tmp2_ = gee_hash_map_new (GITG_EXT_TYPE_NOTIFICATION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_ULONG, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	_g_object_unref0 (self->priv->d_handles);
	self->priv->d_handles = _tmp2_;
	_tmp3_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->priv->d_box);
	self->priv->d_box = _tmp3_;
	_tmp4_ = self->priv->d_box;
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) _tmp4_);
	gtk_style_context_add_class (_tmp5_, "notifications");
	_tmp6_ = self->priv->d_box;
	gtk_widget_show ((GtkWidget*) _tmp6_);
	_tmp7_ = self->priv->d_box;
	gtk_widget_set_valign ((GtkWidget*) _tmp7_, GTK_ALIGN_END);
	_tmp8_ = self->priv->d_overlay;
	_tmp9_ = self->priv->d_box;
	gtk_overlay_add_overlay (_tmp8_, (GtkWidget*) _tmp9_);
	return self;
}

GitgNotifications*
gitg_notifications_new (GtkOverlay* overlay)
{
	return gitg_notifications_construct (GITG_TYPE_NOTIFICATIONS, overlay);
}

static void
gitg_notifications_real_dispose (GObject* base)
{
	GitgNotifications * self;
	GeeHashMap* _tmp9_;
	GeeHashMap* _tmp23_;
	self = (GitgNotifications*) base;
	{
		GeeIterator* _id_it = NULL;
		GeeHashMap* _tmp0_;
		GeeCollection* _tmp1_;
		GeeCollection* _tmp2_;
		GeeCollection* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
		_tmp0_ = self->priv->d_delay_handles;
		_tmp1_ = gee_abstract_map_get_values ((GeeAbstractMap*) _tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
		_tmp5_ = _tmp4_;
		_g_object_unref0 (_tmp3_);
		_id_it = _tmp5_;
		while (TRUE) {
			GeeIterator* _tmp6_;
			guint id = 0U;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			_tmp6_ = _id_it;
			if (!gee_iterator_next (_tmp6_)) {
				break;
			}
			_tmp7_ = _id_it;
			_tmp8_ = gee_iterator_get (_tmp7_);
			id = (guint) ((guintptr) _tmp8_);
			g_source_remove (id);
		}
		_g_object_unref0 (_id_it);
	}
	_tmp9_ = self->priv->d_delay_handles;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp9_);
	{
		GeeIterator* _notification_it = NULL;
		GeeHashMap* _tmp10_;
		GeeSet* _tmp11_;
		GeeSet* _tmp12_;
		GeeSet* _tmp13_;
		GeeIterator* _tmp14_;
		GeeIterator* _tmp15_;
		_tmp10_ = self->priv->d_handles;
		_tmp11_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp10_);
		_tmp12_ = _tmp11_;
		_tmp13_ = _tmp12_;
		_tmp14_ = gee_iterable_iterator ((GeeIterable*) _tmp13_);
		_tmp15_ = _tmp14_;
		_g_object_unref0 (_tmp13_);
		_notification_it = _tmp15_;
		while (TRUE) {
			GeeIterator* _tmp16_;
			GitgExtNotification* notification = NULL;
			GeeIterator* _tmp17_;
			gpointer _tmp18_;
			GitgExtNotification* _tmp19_;
			GeeHashMap* _tmp20_;
			GitgExtNotification* _tmp21_;
			gpointer _tmp22_;
			_tmp16_ = _notification_it;
			if (!gee_iterator_next (_tmp16_)) {
				break;
			}
			_tmp17_ = _notification_it;
			_tmp18_ = gee_iterator_get (_tmp17_);
			notification = (GitgExtNotification*) _tmp18_;
			_tmp19_ = notification;
			_tmp20_ = self->priv->d_handles;
			_tmp21_ = notification;
			_tmp22_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp20_, _tmp21_);
			g_signal_handler_disconnect ((GObject*) _tmp19_, (gulong) ((guintptr) _tmp22_));
			_g_object_unref0 (notification);
		}
		_g_object_unref0 (_notification_it);
	}
	_tmp23_ = self->priv->d_handles;
	gee_abstract_map_clear ((GeeAbstractMap*) _tmp23_);
	G_OBJECT_CLASS (gitg_notifications_parent_class)->dispose (G_TYPE_CHECK_INSTANCE_CAST (self, G_TYPE_OBJECT, GObject));
}

static Block67Data*
block67_data_ref (Block67Data* _data67_)
{
	g_atomic_int_inc (&_data67_->_ref_count_);
	return _data67_;
}

static void
block67_data_unref (void * _userdata_)
{
	Block67Data* _data67_;
	_data67_ = (Block67Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data67_->_ref_count_)) {
		GitgNotifications* self;
		self = _data67_->self;
		_g_object_unref0 (_data67_->notification);
		_g_object_unref0 (self);
		g_slice_free (Block67Data, _data67_);
	}
}

static void
__lambda174_ (Block67Data* _data67_,
              guint delay)
{
	GitgNotifications* self;
	self = _data67_->self;
	gitg_ext_notifications_remove ((GitgExtNotifications*) self, _data67_->notification, delay);
}

static void
___lambda174__gitg_ext_notification_close (GitgExtNotification* _sender,
                                           guint delay,
                                           gpointer self)
{
	__lambda174_ (self, delay);
}

static void
gitg_notifications_real_add (GitgExtNotifications* base,
                             GitgExtNotification* notification)
{
	GitgNotifications * self;
	Block67Data* _data67_;
	GitgExtNotification* _tmp0_;
	GtkRevealer* revealer = NULL;
	GtkRevealer* _tmp1_;
	GtkWidget* _tmp2_;
	GtkWidget* _tmp3_;
	GtkWidget* _tmp4_;
	GtkWidget* _tmp5_;
	GtkWidget* _tmp6_;
	GtkWidget* _tmp7_;
	GtkBox* _tmp8_;
	GeeHashMap* _tmp9_;
	gulong _tmp10_;
	self = (GitgNotifications*) base;
	g_return_if_fail (notification != NULL);
	_data67_ = g_slice_new0 (Block67Data);
	_data67_->_ref_count_ = 1;
	_data67_->self = g_object_ref (self);
	_tmp0_ = _g_object_ref0 (notification);
	_g_object_unref0 (_data67_->notification);
	_data67_->notification = _tmp0_;
	_tmp1_ = (GtkRevealer*) gtk_revealer_new ();
	g_object_ref_sink (_tmp1_);
	revealer = _tmp1_;
	gtk_widget_set_margin_top ((GtkWidget*) revealer, 1);
	gtk_revealer_set_transition_duration (revealer, (guint) 500);
	gtk_revealer_set_transition_type (revealer, GTK_REVEALER_TRANSITION_TYPE_SLIDE_UP);
	_tmp2_ = gitg_ext_notification_get_widget (_data67_->notification);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	gtk_container_add ((GtkContainer*) revealer, _tmp4_);
	_g_object_unref0 (_tmp4_);
	_tmp5_ = gitg_ext_notification_get_widget (_data67_->notification);
	_tmp6_ = _tmp5_;
	_tmp7_ = _tmp6_;
	gtk_widget_show (_tmp7_);
	_g_object_unref0 (_tmp7_);
	gtk_widget_show ((GtkWidget*) revealer);
	_tmp8_ = self->priv->d_box;
	gtk_container_add ((GtkContainer*) _tmp8_, (GtkWidget*) revealer);
	gtk_revealer_set_reveal_child (revealer, TRUE);
	_tmp9_ = self->priv->d_handles;
	_tmp10_ = g_signal_connect_data (_data67_->notification, "close", (GCallback) ___lambda174__gitg_ext_notification_close, block67_data_ref (_data67_), (GClosureNotify) block67_data_unref, 0);
	gee_abstract_map_set ((GeeAbstractMap*) _tmp9_, _data67_->notification, (gpointer) ((guintptr) _tmp10_));
	_g_object_unref0 (revealer);
	block67_data_unref (_data67_);
	_data67_ = NULL;
}

static Block68Data*
block68_data_ref (Block68Data* _data68_)
{
	g_atomic_int_inc (&_data68_->_ref_count_);
	return _data68_;
}

static void
block68_data_unref (void * _userdata_)
{
	Block68Data* _data68_;
	_data68_ = (Block68Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data68_->_ref_count_)) {
		GitgNotifications* self;
		self = _data68_->self;
		_g_object_unref0 (_data68_->revealer);
		_g_object_unref0 (_data68_->notification);
		_g_object_unref0 (self);
		g_slice_free (Block68Data, _data68_);
	}
}

static void
__lambda176_ (Block68Data* _data68_)
{
	GitgNotifications* self;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
	self = _data68_->self;
	_tmp0_ = gitg_ext_notification_get_widget (_data68_->notification);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	gtk_container_remove ((GtkContainer*) _data68_->revealer, _tmp2_);
	_g_object_unref0 (_tmp2_);
	gtk_widget_destroy ((GtkWidget*) _data68_->revealer);
}

static void
___lambda176__g_object_notify (GObject* _sender,
                               GParamSpec* pspec,
                               gpointer self)
{
	__lambda176_ (self);
}

static void
gitg_notifications_remove_now (GitgNotifications* self,
                               GitgExtNotification* notification)
{
	Block68Data* _data68_;
	GitgExtNotification* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
	GtkWidget* _tmp3_;
	GtkContainer* _tmp4_;
	GtkRevealer* _tmp5_;
	GtkRevealer* _tmp6_;
	GeeHashMap* _tmp7_;
	gpointer _tmp8_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (notification != NULL);
	_data68_ = g_slice_new0 (Block68Data);
	_data68_->_ref_count_ = 1;
	_data68_->self = g_object_ref (self);
	_tmp0_ = _g_object_ref0 (notification);
	_g_object_unref0 (_data68_->notification);
	_data68_->notification = _tmp0_;
	_tmp1_ = gitg_ext_notification_get_widget (_data68_->notification);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = gtk_widget_get_parent (_tmp3_);
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gtk_revealer_get_type ()) ? ((GtkRevealer*) _tmp4_) : NULL);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp3_);
	_data68_->revealer = _tmp6_;
	_tmp7_ = self->priv->d_handles;
	_tmp8_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp7_, _data68_->notification);
	g_signal_handler_disconnect ((GObject*) _data68_->notification, (gulong) ((guintptr) _tmp8_));
	g_signal_connect_data ((GObject*) _data68_->revealer, "notify::child-revealed", (GCallback) ___lambda176__g_object_notify, block68_data_ref (_data68_), (GClosureNotify) block68_data_unref, 0);
	gtk_revealer_set_reveal_child (_data68_->revealer, FALSE);
	block68_data_unref (_data68_);
	_data68_ = NULL;
}

static Block69Data*
block69_data_ref (Block69Data* _data69_)
{
	g_atomic_int_inc (&_data69_->_ref_count_);
	return _data69_;
}

static void
block69_data_unref (void * _userdata_)
{
	Block69Data* _data69_;
	_data69_ = (Block69Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data69_->_ref_count_)) {
		GitgNotifications* self;
		self = _data69_->self;
		_g_object_unref0 (_data69_->notification);
		_g_object_unref0 (self);
		g_slice_free (Block69Data, _data69_);
	}
}

static gboolean
__lambda175_ (Block69Data* _data69_)
{
	GitgNotifications* self;
	GeeHashMap* _tmp0_;
	gboolean result;
	self = _data69_->self;
	_tmp0_ = self->priv->d_delay_handles;
	gee_abstract_map_unset ((GeeAbstractMap*) _tmp0_, _data69_->notification, NULL);
	gitg_notifications_remove_now (self, _data69_->notification);
	result = FALSE;
	return result;
}

static gboolean
___lambda175__gsource_func (gpointer self)
{
	gboolean result;
	result = __lambda175_ (self);
	return result;
}

static void
gitg_notifications_real_remove (GitgExtNotifications* base,
                                GitgExtNotification* notification,
                                guint delay)
{
	GitgNotifications * self;
	Block69Data* _data69_;
	GitgExtNotification* _tmp0_;
	GeeHashMap* _tmp1_;
	GeeHashMap* _tmp4_;
	self = (GitgNotifications*) base;
	g_return_if_fail (notification != NULL);
	_data69_ = g_slice_new0 (Block69Data);
	_data69_->_ref_count_ = 1;
	_data69_->self = g_object_ref (self);
	_tmp0_ = _g_object_ref0 (notification);
	_g_object_unref0 (_data69_->notification);
	_data69_->notification = _tmp0_;
	_tmp1_ = self->priv->d_delay_handles;
	if (gee_abstract_map_has_key ((GeeAbstractMap*) _tmp1_, _data69_->notification)) {
		GeeHashMap* _tmp2_;
		gpointer _tmp3_;
		_tmp2_ = self->priv->d_delay_handles;
		_tmp3_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp2_, _data69_->notification);
		g_source_remove ((guint) ((guintptr) _tmp3_));
	}
	_tmp4_ = self->priv->d_delay_handles;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp4_, _data69_->notification, (gpointer) ((guintptr) g_timeout_add_full (G_PRIORITY_DEFAULT, delay, ___lambda175__gsource_func, block69_data_ref (_data69_), block69_data_unref)));
	block69_data_unref (_data69_);
	_data69_ = NULL;
}

static void
gitg_notifications_class_init (GitgNotificationsClass * klass,
                               gpointer klass_data)
{
	gitg_notifications_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgNotifications_private_offset);
	((GObjectClass *) klass)->dispose = (void (*) (GObject*)) gitg_notifications_real_dispose;
	G_OBJECT_CLASS (klass)->finalize = gitg_notifications_finalize;
}

static void
gitg_notifications_gitg_ext_notifications_interface_init (GitgExtNotificationsIface * iface,
                                                          gpointer iface_data)
{
	gitg_notifications_gitg_ext_notifications_parent_iface = g_type_interface_peek_parent (iface);
	iface->add = (void (*) (GitgExtNotifications*, GitgExtNotification*)) gitg_notifications_real_add;
	iface->remove = (void (*) (GitgExtNotifications*, GitgExtNotification*, guint)) gitg_notifications_real_remove;
}

static void
gitg_notifications_instance_init (GitgNotifications * self,
                                  gpointer klass)
{
	self->priv = gitg_notifications_get_instance_private (self);
}

static void
gitg_notifications_finalize (GObject * obj)
{
	GitgNotifications * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_NOTIFICATIONS, GitgNotifications);
	_g_object_unref0 (self->priv->d_overlay);
	_g_object_unref0 (self->priv->d_delay_handles);
	_g_object_unref0 (self->priv->d_box);
	_g_object_unref0 (self->priv->d_handles);
	G_OBJECT_CLASS (gitg_notifications_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_notifications_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgNotificationsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_notifications_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgNotifications), 0, (GInstanceInitFunc) gitg_notifications_instance_init, NULL };
	static const GInterfaceInfo gitg_ext_notifications_info = { (GInterfaceInitFunc) gitg_notifications_gitg_ext_notifications_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gitg_notifications_type_id;
	gitg_notifications_type_id = g_type_register_static (G_TYPE_OBJECT, "GitgNotifications", &g_define_type_info, 0);
	g_type_add_interface_static (gitg_notifications_type_id, GITG_EXT_TYPE_NOTIFICATIONS, &gitg_ext_notifications_info);
	GitgNotifications_private_offset = g_type_add_instance_private (gitg_notifications_type_id, sizeof (GitgNotificationsPrivate));
	return gitg_notifications_type_id;
}

GType
gitg_notifications_get_type (void)
{
	static gsize gitg_notifications_type_id__once = 0;
	if (g_once_init_enter (&gitg_notifications_type_id__once)) {
		GType gitg_notifications_type_id;
		gitg_notifications_type_id = gitg_notifications_get_type_once ();
		g_once_init_leave (&gitg_notifications_type_id__once, gitg_notifications_type_id);
	}
	return gitg_notifications_type_id__once;
}

