/* gitg-create-tag-dialog.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-create-tag-dialog.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2014 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include "libgitg.h"
#include <stdlib.h>
#include <string.h>
#include "config.h"
#include <glib/gi18n-lib.h>
#include <gdk/gdk.h>

#define GITG_CREATE_TAG_DIALOG_version VERSION
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_TYPE_CREATE_TAG_DIALOG (gitg_create_tag_dialog_get_type ())
#define GITG_CREATE_TAG_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_CREATE_TAG_DIALOG, GitgCreateTagDialog))
#define GITG_CREATE_TAG_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_CREATE_TAG_DIALOG, GitgCreateTagDialogClass))
#define GITG_IS_CREATE_TAG_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_CREATE_TAG_DIALOG))
#define GITG_IS_CREATE_TAG_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_CREATE_TAG_DIALOG))
#define GITG_CREATE_TAG_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_CREATE_TAG_DIALOG, GitgCreateTagDialogClass))

typedef struct _GitgCreateTagDialog GitgCreateTagDialog;
typedef struct _GitgCreateTagDialogClass GitgCreateTagDialogClass;
typedef struct _GitgCreateTagDialogPrivate GitgCreateTagDialogPrivate;
enum  {
	GITG_CREATE_TAG_DIALOG_0_PROPERTY,
	GITG_CREATE_TAG_DIALOG_NEW_TAG_NAME_PROPERTY,
	GITG_CREATE_TAG_DIALOG_NEW_TAG_MESSAGE_PROPERTY,
	GITG_CREATE_TAG_DIALOG_NUM_PROPERTIES
};
static GParamSpec* gitg_create_tag_dialog_properties[GITG_CREATE_TAG_DIALOG_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block59Data Block59Data;
#define _g_free0(var) (var = (g_free (var), NULL))

struct _GitgCreateTagDialog {
	GtkDialog parent_instance;
	GitgCreateTagDialogPrivate * priv;
};

struct _GitgCreateTagDialogClass {
	GtkDialogClass parent_class;
};

struct _GitgCreateTagDialogPrivate {
	GtkButton* d_button_create;
	GtkEntry* d_entry_tag_name;
	GtkTextView* d_text_view_message;
	GtkTextTag* d_info_tag;
	gboolean d_is_showing_user_info;
	GitgFontManager* d_font_manager;
};

struct _Block59Data {
	int _ref_count_;
	GitgCreateTagDialog* self;
	GtkTextBuffer* buf;
};

static gint GitgCreateTagDialog_private_offset;
static gpointer gitg_create_tag_dialog_parent_class = NULL;

VALA_EXTERN GType gitg_create_tag_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgCreateTagDialog, g_object_unref)
static void gitg_create_tag_dialog_show_user_info (GitgCreateTagDialog* self);
static void gitg_create_tag_dialog_update_info_tag (GitgCreateTagDialog* self);
VALA_EXTERN GitgCreateTagDialog* gitg_create_tag_dialog_new (GtkWindow* parent);
VALA_EXTERN GitgCreateTagDialog* gitg_create_tag_dialog_construct (GType object_type,
                                                       GtkWindow* parent);
VALA_EXTERN gchar* gitg_create_tag_dialog_get_new_tag_name (GitgCreateTagDialog* self);
VALA_EXTERN gchar* gitg_create_tag_dialog_get_new_tag_message (GitgCreateTagDialog* self);
static GObject * gitg_create_tag_dialog_constructor (GType type,
                                              guint n_construct_properties,
                                              GObjectConstructParam * construct_properties);
static Block59Data* block59_data_ref (Block59Data* _data59_);
static void block59_data_unref (void * _userdata_);
static void _gitg_create_tag_dialog___lambda118_ (GitgCreateTagDialog* self);
static void __gitg_create_tag_dialog___lambda118__gtk_editable_changed (GtkEditable* _sender,
                                                                 gpointer self);
static void _gitg_create_tag_dialog___lambda119_ (GitgCreateTagDialog* self);
static void __gitg_create_tag_dialog___lambda119__gtk_widget_style_updated (GtkWidget* _sender,
                                                                     gpointer self);
static gboolean _gitg_create_tag_dialog___lambda120_ (Block59Data* _data59_);
static gboolean __gitg_create_tag_dialog___lambda120__gtk_widget_focus_in_event (GtkWidget* _sender,
                                                                          GdkEventFocus* event,
                                                                          gpointer self);
static gboolean _gitg_create_tag_dialog___lambda121_ (GitgCreateTagDialog* self);
static gboolean __gitg_create_tag_dialog___lambda121__gtk_widget_focus_out_event (GtkWidget* _sender,
                                                                           GdkEventFocus* event,
                                                                           gpointer self);
static void gitg_create_tag_dialog_finalize (GObject * obj);
static GType gitg_create_tag_dialog_get_type_once (void);
static void _vala_gitg_create_tag_dialog_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec);

static inline gpointer
gitg_create_tag_dialog_get_instance_private (GitgCreateTagDialog* self)
{
	return G_STRUCT_MEMBER_P (self, GitgCreateTagDialog_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
gitg_create_tag_dialog_show_user_info (GitgCreateTagDialog* self)
{
	GtkTextBuffer* buf = NULL;
	GtkTextView* _tmp0_;
	GtkTextBuffer* _tmp1_;
	GtkTextBuffer* _tmp2_;
	GtkTextBuffer* _tmp3_;
	GtkTextIter start = {0};
	GtkTextIter end = {0};
	GtkTextBuffer* _tmp4_;
	GtkTextIter _tmp5_ = {0};
	GtkTextIter _tmp6_ = {0};
	gboolean _tmp7_ = FALSE;
	GtkTextIter _tmp8_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->d_text_view_message;
	_tmp1_ = gtk_text_view_get_buffer (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _g_object_ref0 (_tmp2_);
	buf = _tmp3_;
	_tmp4_ = buf;
	gtk_text_buffer_get_bounds (_tmp4_, &_tmp5_, &_tmp6_);
	start = _tmp5_;
	end = _tmp6_;
	_tmp8_ = end;
	if (gtk_text_iter_compare (&start, &_tmp8_) == 0) {
		GtkTextView* _tmp9_;
		gboolean _tmp10_;
		gboolean _tmp11_;
		_tmp9_ = self->priv->d_text_view_message;
		g_object_get ((GtkWidget*) _tmp9_, "has-focus", &_tmp10_, NULL);
		_tmp11_ = _tmp10_;
		_tmp7_ = !_tmp11_;
	} else {
		_tmp7_ = FALSE;
	}
	if (_tmp7_) {
		GtkTextBuffer* _tmp12_;
		GtkTextTag* _tmp13_;
		_tmp12_ = buf;
		_tmp13_ = self->priv->d_info_tag;
		gtk_text_buffer_insert_with_tags (_tmp12_, &start, _ ("Provide a message to create an annotated tag"), -1, _tmp13_, NULL);
		self->priv->d_is_showing_user_info = TRUE;
	} else {
		self->priv->d_is_showing_user_info = FALSE;
	}
	_g_object_unref0 (buf);
}

static void
gitg_create_tag_dialog_update_info_tag (GitgCreateTagDialog* self)
{
	GtkStyleContext* ctx = NULL;
	GtkTextView* _tmp0_;
	GtkStyleContext* _tmp1_;
	GtkStyleContext* _tmp2_;
	GtkTextTag* _tmp3_;
	GdkRGBA _tmp4_ = {0};
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->d_text_view_message;
	_tmp1_ = gtk_widget_get_style_context ((GtkWidget*) _tmp0_);
	_tmp2_ = _g_object_ref0 (_tmp1_);
	ctx = _tmp2_;
	_tmp3_ = self->priv->d_info_tag;
	gtk_style_context_get_color (ctx, GTK_STATE_FLAG_INSENSITIVE, &_tmp4_);
	g_object_set (_tmp3_, "foreground-rgba", &_tmp4_, NULL);
	_g_object_unref0 (ctx);
}

GitgCreateTagDialog*
gitg_create_tag_dialog_construct (GType object_type,
                                  GtkWindow* parent)
{
	GitgCreateTagDialog * self = NULL;
	self = (GitgCreateTagDialog*) g_object_new (object_type, "use-header-bar", 1, NULL);
	if (parent != NULL) {
		gtk_window_set_transient_for ((GtkWindow*) self, parent);
	}
	return self;
}

GitgCreateTagDialog*
gitg_create_tag_dialog_new (GtkWindow* parent)
{
	return gitg_create_tag_dialog_construct (GITG_TYPE_CREATE_TAG_DIALOG, parent);
}

static gchar*
string_strip (const gchar* self)
{
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = g_strdup (self);
	_result_ = _tmp0_;
	g_strstrip (_result_);
	result = _result_;
	return result;
}

gchar*
gitg_create_tag_dialog_get_new_tag_name (GitgCreateTagDialog* self)
{
	gchar* result;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->d_entry_tag_name;
	_tmp1_ = gtk_entry_get_text (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = string_strip (_tmp2_);
	result = _tmp3_;
	return result;
}

gchar*
gitg_create_tag_dialog_get_new_tag_message (GitgCreateTagDialog* self)
{
	gchar* result;
	GtkTextBuffer* buf = NULL;
	GtkTextView* _tmp1_;
	GtkTextBuffer* _tmp2_;
	GtkTextBuffer* _tmp3_;
	GtkTextBuffer* _tmp4_;
	GtkTextIter start = {0};
	GtkTextIter end = {0};
	GtkTextBuffer* _tmp5_;
	GtkTextIter _tmp6_ = {0};
	GtkTextIter _tmp7_ = {0};
	GtkTextBuffer* _tmp8_;
	GtkTextIter _tmp9_;
	GtkTextIter _tmp10_;
	gchar* _tmp11_;
	g_return_val_if_fail (self != NULL, NULL);
	if (self->priv->d_is_showing_user_info) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup ("");
		result = _tmp0_;
		return result;
	}
	_tmp1_ = self->priv->d_text_view_message;
	_tmp2_ = gtk_text_view_get_buffer (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = _g_object_ref0 (_tmp3_);
	buf = _tmp4_;
	_tmp5_ = buf;
	gtk_text_buffer_get_bounds (_tmp5_, &_tmp6_, &_tmp7_);
	start = _tmp6_;
	end = _tmp7_;
	_tmp8_ = buf;
	_tmp9_ = start;
	_tmp10_ = end;
	_tmp11_ = gtk_text_buffer_get_text (_tmp8_, &_tmp9_, &_tmp10_, FALSE);
	result = _tmp11_;
	_g_object_unref0 (buf);
	return result;
}

static Block59Data*
block59_data_ref (Block59Data* _data59_)
{
	g_atomic_int_inc (&_data59_->_ref_count_);
	return _data59_;
}

static void
block59_data_unref (void * _userdata_)
{
	Block59Data* _data59_;
	_data59_ = (Block59Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data59_->_ref_count_)) {
		GitgCreateTagDialog* self;
		self = _data59_->self;
		_g_object_unref0 (_data59_->buf);
		_g_object_unref0 (self);
		g_slice_free (Block59Data, _data59_);
	}
}

static void
_gitg_create_tag_dialog___lambda118_ (GitgCreateTagDialog* self)
{
	GtkButton* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	_tmp0_ = self->priv->d_button_create;
	_tmp1_ = gitg_create_tag_dialog_get_new_tag_name (self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = strlen (_tmp3_);
	_tmp5_ = _tmp4_;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ != 0);
	_g_free0 (_tmp3_);
}

static void
__gitg_create_tag_dialog___lambda118__gtk_editable_changed (GtkEditable* _sender,
                                                            gpointer self)
{
	_gitg_create_tag_dialog___lambda118_ ((GitgCreateTagDialog*) self);
}

static void
_gitg_create_tag_dialog___lambda119_ (GitgCreateTagDialog* self)
{
	gitg_create_tag_dialog_update_info_tag (self);
}

static void
__gitg_create_tag_dialog___lambda119__gtk_widget_style_updated (GtkWidget* _sender,
                                                                gpointer self)
{
	_gitg_create_tag_dialog___lambda119_ ((GitgCreateTagDialog*) self);
}

static gboolean
_gitg_create_tag_dialog___lambda120_ (Block59Data* _data59_)
{
	GitgCreateTagDialog* self;
	gboolean result;
	self = _data59_->self;
	if (self->priv->d_is_showing_user_info) {
		GtkTextIter start = {0};
		GtkTextIter end = {0};
		GtkTextBuffer* _tmp0_;
		GtkTextIter _tmp1_ = {0};
		GtkTextIter _tmp2_ = {0};
		GtkTextBuffer* _tmp3_;
		_tmp0_ = _data59_->buf;
		gtk_text_buffer_get_bounds (_tmp0_, &_tmp1_, &_tmp2_);
		start = _tmp1_;
		end = _tmp2_;
		_tmp3_ = _data59_->buf;
		gtk_text_buffer_delete (_tmp3_, &start, &end);
	}
	result = FALSE;
	return result;
}

static gboolean
__gitg_create_tag_dialog___lambda120__gtk_widget_focus_in_event (GtkWidget* _sender,
                                                                 GdkEventFocus* event,
                                                                 gpointer self)
{
	gboolean result;
	result = _gitg_create_tag_dialog___lambda120_ (self);
	return result;
}

static gboolean
_gitg_create_tag_dialog___lambda121_ (GitgCreateTagDialog* self)
{
	gboolean result;
	gitg_create_tag_dialog_show_user_info (self);
	result = FALSE;
	return result;
}

static gboolean
__gitg_create_tag_dialog___lambda121__gtk_widget_focus_out_event (GtkWidget* _sender,
                                                                  GdkEventFocus* event,
                                                                  gpointer self)
{
	gboolean result;
	result = _gitg_create_tag_dialog___lambda121_ ((GitgCreateTagDialog*) self);
	return result;
}

static GObject *
gitg_create_tag_dialog_constructor (GType type,
                                    guint n_construct_properties,
                                    GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GitgCreateTagDialog * self;
	Block59Data* _data59_;
	GtkTextView* _tmp0_;
	GitgFontManager* _tmp1_;
	GtkEntry* _tmp2_;
	GtkButton* _tmp3_;
	GtkTextView* _tmp4_;
	GtkTextBuffer* _tmp5_;
	GtkTextBuffer* _tmp6_;
	GtkTextBuffer* _tmp7_;
	GtkTextBuffer* _tmp8_;
	GtkTextTag* _tmp9_;
	GtkTextTag* _tmp10_;
	GtkTextView* _tmp11_;
	GtkTextView* _tmp12_;
	GtkTextView* _tmp13_;
	parent_class = G_OBJECT_CLASS (gitg_create_tag_dialog_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_CREATE_TAG_DIALOG, GitgCreateTagDialog);
	_data59_ = g_slice_new0 (Block59Data);
	_data59_->_ref_count_ = 1;
	_data59_->self = g_object_ref (self);
	_tmp0_ = self->priv->d_text_view_message;
	_tmp1_ = gitg_font_manager_new (_tmp0_, FALSE);
	_g_object_unref0 (self->priv->d_font_manager);
	self->priv->d_font_manager = _tmp1_;
	_tmp2_ = self->priv->d_entry_tag_name;
	g_signal_connect_object ((GtkEditable*) _tmp2_, "changed", (GCallback) __gitg_create_tag_dialog___lambda118__gtk_editable_changed, self, 0);
	_tmp3_ = self->priv->d_button_create;
	gtk_window_set_default ((GtkWindow*) self, (GtkWidget*) _tmp3_);
	_tmp4_ = self->priv->d_text_view_message;
	_tmp5_ = gtk_text_view_get_buffer (_tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = _g_object_ref0 (_tmp6_);
	_data59_->buf = _tmp7_;
	_tmp8_ = _data59_->buf;
	_tmp9_ = gtk_text_buffer_create_tag (_tmp8_, "info", NULL);
	_tmp10_ = _g_object_ref0 (_tmp9_);
	_g_object_unref0 (self->priv->d_info_tag);
	self->priv->d_info_tag = _tmp10_;
	_tmp11_ = self->priv->d_text_view_message;
	g_signal_connect_object ((GtkWidget*) _tmp11_, "style-updated", (GCallback) __gitg_create_tag_dialog___lambda119__gtk_widget_style_updated, self, 0);
	_tmp12_ = self->priv->d_text_view_message;
	g_signal_connect_data ((GtkWidget*) _tmp12_, "focus-in-event", (GCallback) __gitg_create_tag_dialog___lambda120__gtk_widget_focus_in_event, block59_data_ref (_data59_), (GClosureNotify) block59_data_unref, 0);
	_tmp13_ = self->priv->d_text_view_message;
	g_signal_connect_object ((GtkWidget*) _tmp13_, "focus-out-event", (GCallback) __gitg_create_tag_dialog___lambda121__gtk_widget_focus_out_event, self, 0);
	gitg_create_tag_dialog_update_info_tag (self);
	gitg_create_tag_dialog_show_user_info (self);
	gtk_dialog_set_default_response ((GtkDialog*) self, (gint) GTK_RESPONSE_OK);
	block59_data_unref (_data59_);
	_data59_ = NULL;
	return obj;
}

static void
gitg_create_tag_dialog_class_init (GitgCreateTagDialogClass * klass,
                                   gpointer klass_data)
{
	gitg_create_tag_dialog_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgCreateTagDialog_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gitg_create_tag_dialog_get_property;
	G_OBJECT_CLASS (klass)->constructor = gitg_create_tag_dialog_constructor;
	G_OBJECT_CLASS (klass)->finalize = gitg_create_tag_dialog_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_CREATE_TAG_DIALOG_NEW_TAG_NAME_PROPERTY, gitg_create_tag_dialog_properties[GITG_CREATE_TAG_DIALOG_NEW_TAG_NAME_PROPERTY] = g_param_spec_string ("new-tag-name", "new-tag-name", "new-tag-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_CREATE_TAG_DIALOG_NEW_TAG_MESSAGE_PROPERTY, gitg_create_tag_dialog_properties[GITG_CREATE_TAG_DIALOG_NEW_TAG_MESSAGE_PROPERTY] = g_param_spec_string ("new-tag-message", "new-tag-message", "new-tag-message", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/gitg/ui/gitg-create-tag-dialog.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "d_button_create", FALSE, GitgCreateTagDialog_private_offset + G_STRUCT_OFFSET (GitgCreateTagDialogPrivate, d_button_create));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "d_entry_tag_name", FALSE, GitgCreateTagDialog_private_offset + G_STRUCT_OFFSET (GitgCreateTagDialogPrivate, d_entry_tag_name));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "d_text_view_message", FALSE, GitgCreateTagDialog_private_offset + G_STRUCT_OFFSET (GitgCreateTagDialogPrivate, d_text_view_message));
}

static void
gitg_create_tag_dialog_instance_init (GitgCreateTagDialog * self,
                                      gpointer klass)
{
	self->priv = gitg_create_tag_dialog_get_instance_private (self);
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
gitg_create_tag_dialog_finalize (GObject * obj)
{
	GitgCreateTagDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_CREATE_TAG_DIALOG, GitgCreateTagDialog);
	_g_object_unref0 (self->priv->d_info_tag);
	_g_object_unref0 (self->priv->d_font_manager);
	G_OBJECT_CLASS (gitg_create_tag_dialog_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_create_tag_dialog_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgCreateTagDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_create_tag_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgCreateTagDialog), 0, (GInstanceInitFunc) gitg_create_tag_dialog_instance_init, NULL };
	GType gitg_create_tag_dialog_type_id;
	gitg_create_tag_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "GitgCreateTagDialog", &g_define_type_info, 0);
	GitgCreateTagDialog_private_offset = g_type_add_instance_private (gitg_create_tag_dialog_type_id, sizeof (GitgCreateTagDialogPrivate));
	return gitg_create_tag_dialog_type_id;
}

GType
gitg_create_tag_dialog_get_type (void)
{
	static gsize gitg_create_tag_dialog_type_id__once = 0;
	if (g_once_init_enter (&gitg_create_tag_dialog_type_id__once)) {
		GType gitg_create_tag_dialog_type_id;
		gitg_create_tag_dialog_type_id = gitg_create_tag_dialog_get_type_once ();
		g_once_init_leave (&gitg_create_tag_dialog_type_id__once, gitg_create_tag_dialog_type_id);
	}
	return gitg_create_tag_dialog_type_id__once;
}

static void
_vala_gitg_create_tag_dialog_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec)
{
	GitgCreateTagDialog * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_CREATE_TAG_DIALOG, GitgCreateTagDialog);
	switch (property_id) {
		case GITG_CREATE_TAG_DIALOG_NEW_TAG_NAME_PROPERTY:
		g_value_take_string (value, gitg_create_tag_dialog_get_new_tag_name (self));
		break;
		case GITG_CREATE_TAG_DIALOG_NEW_TAG_MESSAGE_PROPERTY:
		g_value_take_string (value, gitg_create_tag_dialog_get_new_tag_message (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

