/* gitg-diff-view-file-renderer-text-split.c generated by valac 0.56.19, the Vala compiler
 * generated from gitg-diff-view-file-renderer-text-split.vala, do not modify */

/*
 * This file is part of gitg
 *
 * Copyright (C) 2016 - Jesse van den Kieboom
 *
 * gitg is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * gitg is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gitg. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include "libgitg.h"
#include <libgit2-glib/ggit.h>
#include <gee.h>
#include <gtksourceview/gtksource.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define GITG_TYPE_DIFF_SELECTABLE (gitg_diff_selectable_get_type ())
#define GITG_DIFF_SELECTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_DIFF_SELECTABLE, GitgDiffSelectable))
#define GITG_IS_DIFF_SELECTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_DIFF_SELECTABLE))
#define GITG_DIFF_SELECTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GITG_TYPE_DIFF_SELECTABLE, GitgDiffSelectableIface))

typedef struct _GitgDiffSelectable GitgDiffSelectable;
typedef struct _GitgDiffSelectableIface GitgDiffSelectableIface;

#define GITG_TYPE_DIFF_VIEW_FILE_RENDERER (gitg_diff_view_file_renderer_get_type ())
#define GITG_DIFF_VIEW_FILE_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER, GitgDiffViewFileRenderer))
#define GITG_IS_DIFF_VIEW_FILE_RENDERER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER))
#define GITG_DIFF_VIEW_FILE_RENDERER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER, GitgDiffViewFileRendererIface))

typedef struct _GitgDiffViewFileRenderer GitgDiffViewFileRenderer;
typedef struct _GitgDiffViewFileRendererIface GitgDiffViewFileRendererIface;

#define GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXTABLE (gitg_diff_view_file_renderer_textable_get_type ())
#define GITG_DIFF_VIEW_FILE_RENDERER_TEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXTABLE, GitgDiffViewFileRendererTextable))
#define GITG_IS_DIFF_VIEW_FILE_RENDERER_TEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXTABLE))
#define GITG_DIFF_VIEW_FILE_RENDERER_TEXTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXTABLE, GitgDiffViewFileRendererTextableIface))

typedef struct _GitgDiffViewFileRendererTextable GitgDiffViewFileRendererTextable;
typedef struct _GitgDiffViewFileRendererTextableIface GitgDiffViewFileRendererTextableIface;

#define GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT (gitg_diff_view_file_renderer_text_split_get_type ())
#define GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT, GitgDiffViewFileRendererTextSplit))
#define GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT, GitgDiffViewFileRendererTextSplitClass))
#define GITG_IS_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT))
#define GITG_IS_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT))
#define GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT, GitgDiffViewFileRendererTextSplitClass))

typedef struct _GitgDiffViewFileRendererTextSplit GitgDiffViewFileRendererTextSplit;
typedef struct _GitgDiffViewFileRendererTextSplitClass GitgDiffViewFileRendererTextSplitClass;
typedef struct _GitgDiffViewFileRendererTextSplitPrivate GitgDiffViewFileRendererTextSplitPrivate;

#define GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT (gitg_diff_view_file_renderer_text_get_type ())
#define GITG_DIFF_VIEW_FILE_RENDERER_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT, GitgDiffViewFileRendererText))
#define GITG_DIFF_VIEW_FILE_RENDERER_TEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT, GitgDiffViewFileRendererTextClass))
#define GITG_IS_DIFF_VIEW_FILE_RENDERER_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT))
#define GITG_IS_DIFF_VIEW_FILE_RENDERER_TEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT))
#define GITG_DIFF_VIEW_FILE_RENDERER_TEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT, GitgDiffViewFileRendererTextClass))

typedef struct _GitgDiffViewFileRendererText GitgDiffViewFileRendererText;
typedef struct _GitgDiffViewFileRendererTextClass GitgDiffViewFileRendererTextClass;

#define GITG_TYPE_DIFF_VIEW_FILE_INFO (gitg_diff_view_file_info_get_type ())
#define GITG_DIFF_VIEW_FILE_INFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_TYPE_DIFF_VIEW_FILE_INFO, GitgDiffViewFileInfo))
#define GITG_DIFF_VIEW_FILE_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_TYPE_DIFF_VIEW_FILE_INFO, GitgDiffViewFileInfoClass))
#define GITG_IS_DIFF_VIEW_FILE_INFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_TYPE_DIFF_VIEW_FILE_INFO))
#define GITG_IS_DIFF_VIEW_FILE_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_TYPE_DIFF_VIEW_FILE_INFO))
#define GITG_DIFF_VIEW_FILE_INFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_TYPE_DIFF_VIEW_FILE_INFO, GitgDiffViewFileInfoClass))

typedef struct _GitgDiffViewFileInfo GitgDiffViewFileInfo;
typedef struct _GitgDiffViewFileInfoClass GitgDiffViewFileInfoClass;
enum  {
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_0_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_INFO_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_DELTA_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_REPOSITORY_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_WRAP_LINES_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_TAB_WIDTH_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_MAXLINES_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HIGHLIGHT_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HAS_SELECTION_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_CAN_SELECT_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_SELECTION_PROPERTY,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_NUM_PROPERTIES
};
static GParamSpec* gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef enum  {
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_STYLE_ONE,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_STYLE_OLD,
	GITG_DIFF_VIEW_FILE_RENDERER_TEXT_STYLE_NEW
} GitgDiffViewFileRendererTextStyle;

#define GITG_DIFF_VIEW_FILE_RENDERER_TEXT_TYPE_STYLE (gitg_diff_view_file_renderer_text_style_get_type ())

struct _GitgDiffSelectableIface {
	GTypeInterface parent_iface;
	void (*clear_selection) (GitgDiffSelectable* self);
	gboolean (*get_has_selection) (GitgDiffSelectable* self);
	gboolean (*get_can_select) (GitgDiffSelectable* self);
	void (*set_can_select) (GitgDiffSelectable* self, gboolean value);
	GitgPatchSet* (*get_selection) (GitgDiffSelectable* self);
};

struct _GitgDiffViewFileRendererIface {
	GTypeInterface parent_iface;
	void (*add_hunk) (GitgDiffViewFileRenderer* self, GgitDiffHunk* hunk, GeeArrayList* lines);
};

struct _GitgDiffViewFileRendererTextableIface {
	GTypeInterface parent_iface;
	gboolean (*get_wrap_lines) (GitgDiffViewFileRendererTextable* self);
	void (*set_wrap_lines) (GitgDiffViewFileRendererTextable* self, gboolean value);
	gint (*get_tab_width) (GitgDiffViewFileRendererTextable* self);
	void (*set_tab_width) (GitgDiffViewFileRendererTextable* self, gint value);
	gint (*get_maxlines) (GitgDiffViewFileRendererTextable* self);
	void (*set_maxlines) (GitgDiffViewFileRendererTextable* self, gint value);
	gboolean (*get_highlight) (GitgDiffViewFileRendererTextable* self);
	void (*set_highlight) (GitgDiffViewFileRendererTextable* self, gboolean value);
};

struct _GitgDiffViewFileRendererTextSplit {
	GtkBox parent_instance;
	GitgDiffViewFileRendererTextSplitPrivate * priv;
};

struct _GitgDiffViewFileRendererTextSplitClass {
	GtkBoxClass parent_class;
};

struct _GitgDiffViewFileRendererTextSplitPrivate {
	GtkScrolledWindow* d_scroll_left;
	GtkScrolledWindow* d_scroll_right;
	GitgDiffViewFileRendererText* d_renderer_left;
	GitgDiffViewFileRendererText* d_renderer_right;
	GitgDiffViewFileInfo* _info;
	gboolean _can_select;
};

static gint GitgDiffViewFileRendererTextSplit_private_offset;
static gpointer gitg_diff_view_file_renderer_text_split_parent_class = NULL;
static GitgDiffSelectableIface * gitg_diff_view_file_renderer_text_split_gitg_diff_selectable_parent_iface = NULL;
static GitgDiffViewFileRendererIface * gitg_diff_view_file_renderer_text_split_gitg_diff_view_file_renderer_parent_iface = NULL;
static GitgDiffViewFileRendererTextableIface * gitg_diff_view_file_renderer_text_split_gitg_diff_view_file_renderer_textable_parent_iface = NULL;

VALA_EXTERN GType gitg_diff_selectable_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType gitg_diff_view_file_renderer_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType gitg_diff_view_file_renderer_textable_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType gitg_diff_view_file_renderer_text_split_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType gitg_diff_view_file_renderer_text_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType gitg_diff_view_file_info_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GitgDiffViewFileRendererTextSplit* gitg_diff_view_file_renderer_text_split_new (GitgDiffViewFileInfo* info,
                                                                                gboolean handle_selection);
VALA_EXTERN GitgDiffViewFileRendererTextSplit* gitg_diff_view_file_renderer_text_split_construct (GType object_type,
                                                                                      GitgDiffViewFileInfo* info,
                                                                                      gboolean handle_selection);
VALA_EXTERN GType gitg_diff_view_file_renderer_text_style_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GitgDiffViewFileRendererText* gitg_diff_view_file_renderer_text_new (GitgDiffViewFileInfo* info,
                                                                     gboolean can_select,
                                                                     GitgDiffViewFileRendererTextStyle style);
VALA_EXTERN GitgDiffViewFileRendererText* gitg_diff_view_file_renderer_text_construct (GType object_type,
                                                                           GitgDiffViewFileInfo* info,
                                                                           gboolean can_select,
                                                                           GitgDiffViewFileRendererTextStyle style);
static void gitg_diff_view_file_renderer_text_split_real_add_hunk (GitgDiffViewFileRenderer* base,
                                                            GgitDiffHunk* hunk,
                                                            GeeArrayList* lines);
VALA_EXTERN void gitg_diff_view_file_renderer_add_hunk (GitgDiffViewFileRenderer* self,
                                            GgitDiffHunk* hunk,
                                            GeeArrayList* lines);
static void gitg_diff_view_file_renderer_text_split_real_clear_selection (GitgDiffSelectable* base);
VALA_EXTERN GitgDiffViewFileInfo* gitg_diff_view_file_renderer_text_split_get_info (GitgDiffViewFileRendererTextSplit* self);
VALA_EXTERN void gitg_diff_view_file_renderer_text_split_set_info (GitgDiffViewFileRendererTextSplit* self,
                                                       GitgDiffViewFileInfo* value);
VALA_EXTERN GgitDiffDelta* gitg_diff_view_file_renderer_text_split_get_delta (GitgDiffViewFileRendererTextSplit* self);
VALA_EXTERN GgitDiffDelta* gitg_diff_view_file_info_get_delta (GitgDiffViewFileInfo* self);
VALA_EXTERN GitgRepository* gitg_diff_view_file_renderer_text_split_get_repository (GitgDiffViewFileRendererTextSplit* self);
VALA_EXTERN GitgRepository* gitg_diff_view_file_info_get_repository (GitgDiffViewFileInfo* self);
VALA_EXTERN gint gitg_diff_view_file_renderer_textable_get_maxlines (GitgDiffViewFileRendererTextable* self);
VALA_EXTERN void gitg_diff_view_file_renderer_textable_set_maxlines (GitgDiffViewFileRendererTextable* self,
                                                         gint value);
VALA_EXTERN gboolean gitg_diff_view_file_renderer_textable_get_highlight (GitgDiffViewFileRendererTextable* self);
VALA_EXTERN void gitg_diff_view_file_renderer_textable_set_highlight (GitgDiffViewFileRendererTextable* self,
                                                          gboolean value);
static GObject * gitg_diff_view_file_renderer_text_split_constructor (GType type,
                                                               guint n_construct_properties,
                                                               GObjectConstructParam * construct_properties);
VALA_EXTERN void gitg_diff_selectable_set_can_select (GitgDiffSelectable* self,
                                          gboolean value);
VALA_EXTERN void gitg_diff_selectable_clear_selection (GitgDiffSelectable* self);
VALA_EXTERN gboolean gitg_diff_selectable_get_has_selection (GitgDiffSelectable* self);
VALA_EXTERN gboolean gitg_diff_selectable_get_can_select (GitgDiffSelectable* self);
VALA_EXTERN GitgPatchSet* gitg_diff_selectable_get_selection (GitgDiffSelectable* self);
VALA_EXTERN gboolean gitg_diff_view_file_renderer_textable_get_wrap_lines (GitgDiffViewFileRendererTextable* self);
VALA_EXTERN void gitg_diff_view_file_renderer_textable_set_wrap_lines (GitgDiffViewFileRendererTextable* self,
                                                           gboolean value);
VALA_EXTERN gint gitg_diff_view_file_renderer_textable_get_tab_width (GitgDiffViewFileRendererTextable* self);
VALA_EXTERN void gitg_diff_view_file_renderer_textable_set_tab_width (GitgDiffViewFileRendererTextable* self,
                                                          gint value);
static void gitg_diff_view_file_renderer_text_split_finalize (GObject * obj);
static GType gitg_diff_view_file_renderer_text_split_get_type_once (void);
static void _vala_gitg_diff_view_file_renderer_text_split_get_property (GObject * object,
                                                                 guint property_id,
                                                                 GValue * value,
                                                                 GParamSpec * pspec);
static void _vala_gitg_diff_view_file_renderer_text_split_set_property (GObject * object,
                                                                 guint property_id,
                                                                 const GValue * value,
                                                                 GParamSpec * pspec);

static inline gpointer
gitg_diff_view_file_renderer_text_split_get_instance_private (GitgDiffViewFileRendererTextSplit* self)
{
	return G_STRUCT_MEMBER_P (self, GitgDiffViewFileRendererTextSplit_private_offset);
}

GitgDiffViewFileRendererTextSplit*
gitg_diff_view_file_renderer_text_split_construct (GType object_type,
                                                   GitgDiffViewFileInfo* info,
                                                   gboolean handle_selection)
{
	GitgDiffViewFileRendererTextSplit * self = NULL;
	GitgDiffViewFileRendererText* _tmp0_;
	GitgDiffViewFileRendererText* _tmp1_;
	GtkScrolledWindow* _tmp2_;
	GitgDiffViewFileRendererText* _tmp3_;
	GtkScrolledWindow* _tmp4_;
	GitgDiffViewFileRendererText* _tmp5_;
	g_return_val_if_fail (info != NULL, NULL);
	self = (GitgDiffViewFileRendererTextSplit*) g_object_new (object_type, "info", info, NULL);
	_tmp0_ = gitg_diff_view_file_renderer_text_new (info, handle_selection, GITG_DIFF_VIEW_FILE_RENDERER_TEXT_STYLE_OLD);
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->d_renderer_left);
	self->priv->d_renderer_left = _tmp0_;
	_tmp1_ = gitg_diff_view_file_renderer_text_new (info, handle_selection, GITG_DIFF_VIEW_FILE_RENDERER_TEXT_STYLE_NEW);
	g_object_ref_sink (_tmp1_);
	_g_object_unref0 (self->priv->d_renderer_right);
	self->priv->d_renderer_right = _tmp1_;
	_tmp2_ = self->priv->d_scroll_left;
	_tmp3_ = self->priv->d_renderer_left;
	gtk_container_add ((GtkContainer*) _tmp2_, (GtkWidget*) _tmp3_);
	_tmp4_ = self->priv->d_scroll_right;
	_tmp5_ = self->priv->d_renderer_right;
	gtk_container_add ((GtkContainer*) _tmp4_, (GtkWidget*) _tmp5_);
	return self;
}

GitgDiffViewFileRendererTextSplit*
gitg_diff_view_file_renderer_text_split_new (GitgDiffViewFileInfo* info,
                                             gboolean handle_selection)
{
	return gitg_diff_view_file_renderer_text_split_construct (GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT, info, handle_selection);
}

static void
gitg_diff_view_file_renderer_text_split_real_add_hunk (GitgDiffViewFileRenderer* base,
                                                       GgitDiffHunk* hunk,
                                                       GeeArrayList* lines)
{
	GitgDiffViewFileRendererTextSplit * self;
	GitgDiffViewFileRendererText* _tmp0_;
	GitgDiffViewFileRendererText* _tmp1_;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	g_return_if_fail (hunk != NULL);
	g_return_if_fail (lines != NULL);
	_tmp0_ = self->priv->d_renderer_left;
	gitg_diff_view_file_renderer_add_hunk ((GitgDiffViewFileRenderer*) _tmp0_, hunk, lines);
	_tmp1_ = self->priv->d_renderer_right;
	gitg_diff_view_file_renderer_add_hunk ((GitgDiffViewFileRenderer*) _tmp1_, hunk, lines);
}

static void
gitg_diff_view_file_renderer_text_split_real_clear_selection (GitgDiffSelectable* base)
{
	GitgDiffViewFileRendererTextSplit * self;
	self = (GitgDiffViewFileRendererTextSplit*) base;
}

GitgDiffViewFileInfo*
gitg_diff_view_file_renderer_text_split_get_info (GitgDiffViewFileRendererTextSplit* self)
{
	GitgDiffViewFileInfo* result;
	GitgDiffViewFileInfo* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_info;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
gitg_diff_view_file_renderer_text_split_set_info (GitgDiffViewFileRendererTextSplit* self,
                                                  GitgDiffViewFileInfo* value)
{
	GitgDiffViewFileInfo* old_value;
	g_return_if_fail (self != NULL);
	old_value = gitg_diff_view_file_renderer_text_split_get_info (self);
	if (old_value != value) {
		GitgDiffViewFileInfo* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_info);
		self->priv->_info = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_INFO_PROPERTY]);
	}
}

GgitDiffDelta*
gitg_diff_view_file_renderer_text_split_get_delta (GitgDiffViewFileRendererTextSplit* self)
{
	GgitDiffDelta* result;
	GitgDiffViewFileInfo* _tmp0_;
	GgitDiffDelta* _tmp1_;
	GgitDiffDelta* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_info;
	_tmp1_ = gitg_diff_view_file_info_get_delta (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

GitgRepository*
gitg_diff_view_file_renderer_text_split_get_repository (GitgDiffViewFileRendererTextSplit* self)
{
	GitgRepository* result;
	GitgDiffViewFileInfo* _tmp0_;
	GitgRepository* _tmp1_;
	GitgRepository* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_info;
	_tmp1_ = gitg_diff_view_file_info_get_repository (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

static gboolean
gitg_diff_view_file_renderer_text_split_real_get_wrap_lines (GitgDiffViewFileRendererTextable* base)
{
	gboolean result;
	GitgDiffViewFileRendererTextSplit* self;
	GitgDiffViewFileRendererText* _tmp0_;
	GtkWrapMode _tmp1_;
	GtkWrapMode _tmp2_;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	_tmp0_ = self->priv->d_renderer_left;
	_tmp1_ = gtk_text_view_get_wrap_mode ((GtkTextView*) _tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_ != GTK_WRAP_NONE;
	return result;
}

static void
gitg_diff_view_file_renderer_text_split_real_set_wrap_lines (GitgDiffViewFileRendererTextable* base,
                                                             gboolean value)
{
	GitgDiffViewFileRendererTextSplit* self;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	if (value) {
		GitgDiffViewFileRendererText* _tmp0_;
		GitgDiffViewFileRendererText* _tmp1_;
		_tmp0_ = self->priv->d_renderer_left;
		gtk_text_view_set_wrap_mode ((GtkTextView*) _tmp0_, GTK_WRAP_WORD_CHAR);
		_tmp1_ = self->priv->d_renderer_right;
		gtk_text_view_set_wrap_mode ((GtkTextView*) _tmp1_, GTK_WRAP_WORD_CHAR);
	} else {
		GitgDiffViewFileRendererText* _tmp2_;
		GitgDiffViewFileRendererText* _tmp3_;
		_tmp2_ = self->priv->d_renderer_left;
		gtk_text_view_set_wrap_mode ((GtkTextView*) _tmp2_, GTK_WRAP_NONE);
		_tmp3_ = self->priv->d_renderer_right;
		gtk_text_view_set_wrap_mode ((GtkTextView*) _tmp3_, GTK_WRAP_NONE);
	}
	g_object_notify_by_pspec ((GObject *) self, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_WRAP_LINES_PROPERTY]);
}

static gint
gitg_diff_view_file_renderer_text_split_real_get_tab_width (GitgDiffViewFileRendererTextable* base)
{
	gint result;
	GitgDiffViewFileRendererTextSplit* self;
	GitgDiffViewFileRendererText* _tmp0_;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	_tmp0_ = self->priv->d_renderer_left;
	result = (gint) gtk_source_view_get_tab_width ((GtkSourceView*) _tmp0_);
	return result;
}

static void
gitg_diff_view_file_renderer_text_split_real_set_tab_width (GitgDiffViewFileRendererTextable* base,
                                                            gint value)
{
	GitgDiffViewFileRendererTextSplit* self;
	GitgDiffViewFileRendererText* _tmp0_;
	GitgDiffViewFileRendererText* _tmp1_;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	_tmp0_ = self->priv->d_renderer_left;
	gtk_source_view_set_tab_width ((GtkSourceView*) _tmp0_, (guint) value);
	_tmp1_ = self->priv->d_renderer_right;
	gtk_source_view_set_tab_width ((GtkSourceView*) _tmp1_, (guint) value);
	g_object_notify_by_pspec ((GObject *) self, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_TAB_WIDTH_PROPERTY]);
}

static gint
gitg_diff_view_file_renderer_text_split_real_get_maxlines (GitgDiffViewFileRendererTextable* base)
{
	gint result;
	GitgDiffViewFileRendererTextSplit* self;
	GitgDiffViewFileRendererText* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	_tmp0_ = self->priv->d_renderer_left;
	_tmp1_ = gitg_diff_view_file_renderer_textable_get_maxlines ((GitgDiffViewFileRendererTextable*) _tmp0_);
	_tmp2_ = _tmp1_;
	result = (gint) _tmp2_;
	return result;
}

static void
gitg_diff_view_file_renderer_text_split_real_set_maxlines (GitgDiffViewFileRendererTextable* base,
                                                           gint value)
{
	GitgDiffViewFileRendererTextSplit* self;
	GitgDiffViewFileRendererText* _tmp0_;
	GitgDiffViewFileRendererText* _tmp1_;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	_tmp0_ = self->priv->d_renderer_left;
	gitg_diff_view_file_renderer_textable_set_maxlines ((GitgDiffViewFileRendererTextable*) _tmp0_, value);
	_tmp1_ = self->priv->d_renderer_right;
	gitg_diff_view_file_renderer_textable_set_maxlines ((GitgDiffViewFileRendererTextable*) _tmp1_, value);
	g_object_notify_by_pspec ((GObject *) self, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_MAXLINES_PROPERTY]);
}

static gboolean
gitg_diff_view_file_renderer_text_split_real_get_highlight (GitgDiffViewFileRendererTextable* base)
{
	gboolean result;
	GitgDiffViewFileRendererTextSplit* self;
	gboolean _tmp0_ = FALSE;
	GitgDiffViewFileRendererText* _tmp1_;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	_tmp1_ = self->priv->d_renderer_left;
	if (_tmp1_ != NULL) {
		GitgDiffViewFileRendererText* _tmp2_;
		gboolean _tmp3_;
		gboolean _tmp4_;
		_tmp2_ = self->priv->d_renderer_left;
		_tmp3_ = gitg_diff_view_file_renderer_textable_get_highlight ((GitgDiffViewFileRendererTextable*) _tmp2_);
		_tmp4_ = _tmp3_;
		_tmp0_ = _tmp4_;
	} else {
		_tmp0_ = FALSE;
	}
	result = _tmp0_;
	return result;
}

static void
gitg_diff_view_file_renderer_text_split_real_set_highlight (GitgDiffViewFileRendererTextable* base,
                                                            gboolean value)
{
	GitgDiffViewFileRendererTextSplit* self;
	gboolean _tmp0_;
	gboolean _tmp1_;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	_tmp0_ = gitg_diff_view_file_renderer_textable_get_highlight ((GitgDiffViewFileRendererTextable*) self);
	_tmp1_ = _tmp0_;
	if (_tmp1_ != value) {
		GitgDiffViewFileRendererText* _tmp2_;
		GitgDiffViewFileRendererText* _tmp3_;
		_tmp2_ = self->priv->d_renderer_left;
		gitg_diff_view_file_renderer_textable_set_highlight ((GitgDiffViewFileRendererTextable*) _tmp2_, value);
		_tmp3_ = self->priv->d_renderer_right;
		gitg_diff_view_file_renderer_textable_set_highlight ((GitgDiffViewFileRendererTextable*) _tmp3_, value);
	}
	g_object_notify_by_pspec ((GObject *) self, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HIGHLIGHT_PROPERTY]);
}

static gboolean
gitg_diff_view_file_renderer_text_split_real_get_has_selection (GitgDiffSelectable* base)
{
	gboolean result;
	GitgDiffViewFileRendererTextSplit* self;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	result = FALSE;
	return result;
}

static gboolean
gitg_diff_view_file_renderer_text_split_real_get_can_select (GitgDiffSelectable* base)
{
	gboolean result;
	GitgDiffViewFileRendererTextSplit* self;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	result = self->priv->_can_select;
	return result;
}

static void
gitg_diff_view_file_renderer_text_split_real_set_can_select (GitgDiffSelectable* base,
                                                             gboolean value)
{
	GitgDiffViewFileRendererTextSplit* self;
	gboolean old_value;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	old_value = gitg_diff_view_file_renderer_text_split_real_get_can_select (base);
	if (old_value != value) {
		self->priv->_can_select = value;
		g_object_notify_by_pspec ((GObject *) self, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_CAN_SELECT_PROPERTY]);
	}
}

static GitgPatchSet*
gitg_diff_view_file_renderer_text_split_real_get_selection (GitgDiffSelectable* base)
{
	GitgPatchSet* result;
	GitgDiffViewFileRendererTextSplit* self;
	GitgPatchSet* _tmp0_;
	self = (GitgDiffViewFileRendererTextSplit*) base;
	_tmp0_ = gitg_patch_set_new ();
	result = _tmp0_;
	return result;
}

static GObject *
gitg_diff_view_file_renderer_text_split_constructor (GType type,
                                                     guint n_construct_properties,
                                                     GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	GitgDiffViewFileRendererTextSplit * self;
	parent_class = G_OBJECT_CLASS (gitg_diff_view_file_renderer_text_split_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT, GitgDiffViewFileRendererTextSplit);
	gitg_diff_selectable_set_can_select ((GitgDiffSelectable*) self, FALSE);
	return obj;
}

static void
gitg_diff_view_file_renderer_text_split_class_init (GitgDiffViewFileRendererTextSplitClass * klass,
                                                    gpointer klass_data)
{
	gitg_diff_view_file_renderer_text_split_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &GitgDiffViewFileRendererTextSplit_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_gitg_diff_view_file_renderer_text_split_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gitg_diff_view_file_renderer_text_split_set_property;
	G_OBJECT_CLASS (klass)->constructor = gitg_diff_view_file_renderer_text_split_constructor;
	G_OBJECT_CLASS (klass)->finalize = gitg_diff_view_file_renderer_text_split_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_INFO_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_INFO_PROPERTY] = g_param_spec_object ("info", "info", "info", GITG_TYPE_DIFF_VIEW_FILE_INFO, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_DELTA_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_DELTA_PROPERTY] = g_param_spec_boxed ("delta", "delta", "delta", ggit_diff_delta_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_REPOSITORY_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_REPOSITORY_PROPERTY] = g_param_spec_object ("repository", "repository", "repository", GITG_TYPE_REPOSITORY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_WRAP_LINES_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_WRAP_LINES_PROPERTY] = g_param_spec_boolean ("wrap-lines", "wrap-lines", "wrap-lines", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_TAB_WIDTH_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_TAB_WIDTH_PROPERTY] = g_param_spec_int ("tab-width", "tab-width", "tab-width", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_MAXLINES_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_MAXLINES_PROPERTY] = g_param_spec_int ("maxlines", "maxlines", "maxlines", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HIGHLIGHT_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HIGHLIGHT_PROPERTY] = g_param_spec_boolean ("highlight", "highlight", "highlight", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HAS_SELECTION_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HAS_SELECTION_PROPERTY] = g_param_spec_boolean ("has-selection", "has-selection", "has-selection", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_CAN_SELECT_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_CAN_SELECT_PROPERTY] = g_param_spec_boolean ("can-select", "can-select", "can-select", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_SELECTION_PROPERTY, gitg_diff_view_file_renderer_text_split_properties[GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_SELECTION_PROPERTY] = gitg_param_spec_patch_set ("selection", "selection", "selection", GITG_TYPE_PATCH_SET, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/gitg/ui/gitg-diff-view-file-renderer-text-split.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "scroll_left", FALSE, GitgDiffViewFileRendererTextSplit_private_offset + G_STRUCT_OFFSET (GitgDiffViewFileRendererTextSplitPrivate, d_scroll_left));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "scroll_right", FALSE, GitgDiffViewFileRendererTextSplit_private_offset + G_STRUCT_OFFSET (GitgDiffViewFileRendererTextSplitPrivate, d_scroll_right));
}

static void
gitg_diff_view_file_renderer_text_split_gitg_diff_selectable_interface_init (GitgDiffSelectableIface * iface,
                                                                             gpointer iface_data)
{
	gitg_diff_view_file_renderer_text_split_gitg_diff_selectable_parent_iface = g_type_interface_peek_parent (iface);
	iface->clear_selection = (void (*) (GitgDiffSelectable*)) gitg_diff_view_file_renderer_text_split_real_clear_selection;
	iface->get_has_selection = gitg_diff_view_file_renderer_text_split_real_get_has_selection;
	iface->get_can_select = gitg_diff_view_file_renderer_text_split_real_get_can_select;
	iface->set_can_select = gitg_diff_view_file_renderer_text_split_real_set_can_select;
	iface->get_selection = gitg_diff_view_file_renderer_text_split_real_get_selection;
}

static void
gitg_diff_view_file_renderer_text_split_gitg_diff_view_file_renderer_interface_init (GitgDiffViewFileRendererIface * iface,
                                                                                     gpointer iface_data)
{
	gitg_diff_view_file_renderer_text_split_gitg_diff_view_file_renderer_parent_iface = g_type_interface_peek_parent (iface);
	iface->add_hunk = (void (*) (GitgDiffViewFileRenderer*, GgitDiffHunk*, GeeArrayList*)) gitg_diff_view_file_renderer_text_split_real_add_hunk;
}

static void
gitg_diff_view_file_renderer_text_split_gitg_diff_view_file_renderer_textable_interface_init (GitgDiffViewFileRendererTextableIface * iface,
                                                                                              gpointer iface_data)
{
	gitg_diff_view_file_renderer_text_split_gitg_diff_view_file_renderer_textable_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_wrap_lines = gitg_diff_view_file_renderer_text_split_real_get_wrap_lines;
	iface->set_wrap_lines = gitg_diff_view_file_renderer_text_split_real_set_wrap_lines;
	iface->get_tab_width = gitg_diff_view_file_renderer_text_split_real_get_tab_width;
	iface->set_tab_width = gitg_diff_view_file_renderer_text_split_real_set_tab_width;
	iface->get_maxlines = gitg_diff_view_file_renderer_text_split_real_get_maxlines;
	iface->set_maxlines = gitg_diff_view_file_renderer_text_split_real_set_maxlines;
	iface->get_highlight = gitg_diff_view_file_renderer_text_split_real_get_highlight;
	iface->set_highlight = gitg_diff_view_file_renderer_text_split_real_set_highlight;
}

static void
gitg_diff_view_file_renderer_text_split_instance_init (GitgDiffViewFileRendererTextSplit * self,
                                                       gpointer klass)
{
	self->priv = gitg_diff_view_file_renderer_text_split_get_instance_private (self);
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
gitg_diff_view_file_renderer_text_split_finalize (GObject * obj)
{
	GitgDiffViewFileRendererTextSplit * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT, GitgDiffViewFileRendererTextSplit);
	_g_object_unref0 (self->priv->d_renderer_left);
	_g_object_unref0 (self->priv->d_renderer_right);
	_g_object_unref0 (self->priv->_info);
	G_OBJECT_CLASS (gitg_diff_view_file_renderer_text_split_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
gitg_diff_view_file_renderer_text_split_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (GitgDiffViewFileRendererTextSplitClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gitg_diff_view_file_renderer_text_split_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GitgDiffViewFileRendererTextSplit), 0, (GInstanceInitFunc) gitg_diff_view_file_renderer_text_split_instance_init, NULL };
	static const GInterfaceInfo gitg_diff_selectable_info = { (GInterfaceInitFunc) gitg_diff_view_file_renderer_text_split_gitg_diff_selectable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_diff_view_file_renderer_info = { (GInterfaceInitFunc) gitg_diff_view_file_renderer_text_split_gitg_diff_view_file_renderer_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	static const GInterfaceInfo gitg_diff_view_file_renderer_textable_info = { (GInterfaceInitFunc) gitg_diff_view_file_renderer_text_split_gitg_diff_view_file_renderer_textable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType gitg_diff_view_file_renderer_text_split_type_id;
	gitg_diff_view_file_renderer_text_split_type_id = g_type_register_static (gtk_box_get_type (), "GitgDiffViewFileRendererTextSplit", &g_define_type_info, 0);
	g_type_add_interface_static (gitg_diff_view_file_renderer_text_split_type_id, GITG_TYPE_DIFF_SELECTABLE, &gitg_diff_selectable_info);
	g_type_add_interface_static (gitg_diff_view_file_renderer_text_split_type_id, GITG_TYPE_DIFF_VIEW_FILE_RENDERER, &gitg_diff_view_file_renderer_info);
	g_type_add_interface_static (gitg_diff_view_file_renderer_text_split_type_id, GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXTABLE, &gitg_diff_view_file_renderer_textable_info);
	GitgDiffViewFileRendererTextSplit_private_offset = g_type_add_instance_private (gitg_diff_view_file_renderer_text_split_type_id, sizeof (GitgDiffViewFileRendererTextSplitPrivate));
	return gitg_diff_view_file_renderer_text_split_type_id;
}

GType
gitg_diff_view_file_renderer_text_split_get_type (void)
{
	static gsize gitg_diff_view_file_renderer_text_split_type_id__once = 0;
	if (g_once_init_enter (&gitg_diff_view_file_renderer_text_split_type_id__once)) {
		GType gitg_diff_view_file_renderer_text_split_type_id;
		gitg_diff_view_file_renderer_text_split_type_id = gitg_diff_view_file_renderer_text_split_get_type_once ();
		g_once_init_leave (&gitg_diff_view_file_renderer_text_split_type_id__once, gitg_diff_view_file_renderer_text_split_type_id);
	}
	return gitg_diff_view_file_renderer_text_split_type_id__once;
}

static void
_vala_gitg_diff_view_file_renderer_text_split_get_property (GObject * object,
                                                            guint property_id,
                                                            GValue * value,
                                                            GParamSpec * pspec)
{
	GitgDiffViewFileRendererTextSplit * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT, GitgDiffViewFileRendererTextSplit);
	switch (property_id) {
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_INFO_PROPERTY:
		g_value_set_object (value, gitg_diff_view_file_renderer_text_split_get_info (self));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_DELTA_PROPERTY:
		g_value_set_boxed (value, gitg_diff_view_file_renderer_text_split_get_delta (self));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_REPOSITORY_PROPERTY:
		g_value_set_object (value, gitg_diff_view_file_renderer_text_split_get_repository (self));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_WRAP_LINES_PROPERTY:
		g_value_set_boolean (value, gitg_diff_view_file_renderer_textable_get_wrap_lines ((GitgDiffViewFileRendererTextable*) self));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_TAB_WIDTH_PROPERTY:
		g_value_set_int (value, gitg_diff_view_file_renderer_textable_get_tab_width ((GitgDiffViewFileRendererTextable*) self));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_MAXLINES_PROPERTY:
		g_value_set_int (value, gitg_diff_view_file_renderer_textable_get_maxlines ((GitgDiffViewFileRendererTextable*) self));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HIGHLIGHT_PROPERTY:
		g_value_set_boolean (value, gitg_diff_view_file_renderer_textable_get_highlight ((GitgDiffViewFileRendererTextable*) self));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HAS_SELECTION_PROPERTY:
		g_value_set_boolean (value, gitg_diff_selectable_get_has_selection ((GitgDiffSelectable*) self));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_CAN_SELECT_PROPERTY:
		g_value_set_boolean (value, gitg_diff_selectable_get_can_select ((GitgDiffSelectable*) self));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_SELECTION_PROPERTY:
		gitg_value_take_patch_set (value, gitg_diff_selectable_get_selection ((GitgDiffSelectable*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_gitg_diff_view_file_renderer_text_split_set_property (GObject * object,
                                                            guint property_id,
                                                            const GValue * value,
                                                            GParamSpec * pspec)
{
	GitgDiffViewFileRendererTextSplit * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GITG_TYPE_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT, GitgDiffViewFileRendererTextSplit);
	switch (property_id) {
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_INFO_PROPERTY:
		gitg_diff_view_file_renderer_text_split_set_info (self, g_value_get_object (value));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_WRAP_LINES_PROPERTY:
		gitg_diff_view_file_renderer_textable_set_wrap_lines ((GitgDiffViewFileRendererTextable*) self, g_value_get_boolean (value));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_TAB_WIDTH_PROPERTY:
		gitg_diff_view_file_renderer_textable_set_tab_width ((GitgDiffViewFileRendererTextable*) self, g_value_get_int (value));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_MAXLINES_PROPERTY:
		gitg_diff_view_file_renderer_textable_set_maxlines ((GitgDiffViewFileRendererTextable*) self, g_value_get_int (value));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_HIGHLIGHT_PROPERTY:
		gitg_diff_view_file_renderer_textable_set_highlight ((GitgDiffViewFileRendererTextable*) self, g_value_get_boolean (value));
		break;
		case GITG_DIFF_VIEW_FILE_RENDERER_TEXT_SPLIT_CAN_SELECT_PROPERTY:
		gitg_diff_selectable_set_can_select ((GitgDiffSelectable*) self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

