/* files.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __PLUGINS_FILES_FILES_H__
#define __PLUGINS_FILES_FILES_H__

#include <glib-object.h>
#include "libgitg-ext.h"
#include <glib.h>
#include <gtk/gtk.h>
#include <libgit2-glib/ggit.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GITG_FILES_TYPE_PANEL (gitg_files_panel_get_type ())
#define GITG_FILES_PANEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_FILES_TYPE_PANEL, GitgFilesPanel))
#define GITG_FILES_PANEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_FILES_TYPE_PANEL, GitgFilesPanelClass))
#define GITG_FILES_IS_PANEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_FILES_TYPE_PANEL))
#define GITG_FILES_IS_PANEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_FILES_TYPE_PANEL))
#define GITG_FILES_PANEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_FILES_TYPE_PANEL, GitgFilesPanelClass))

typedef struct _GitgFilesPanel GitgFilesPanel;
typedef struct _GitgFilesPanelClass GitgFilesPanelClass;
typedef struct _GitgFilesPanelPrivate GitgFilesPanelPrivate;

#define GITG_FILES_TYPE_TREE_STORE (gitg_files_tree_store_get_type ())
#define GITG_FILES_TREE_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GITG_FILES_TYPE_TREE_STORE, GitgFilesTreeStore))
#define GITG_FILES_TREE_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GITG_FILES_TYPE_TREE_STORE, GitgFilesTreeStoreClass))
#define GITG_FILES_IS_TREE_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GITG_FILES_TYPE_TREE_STORE))
#define GITG_FILES_IS_TREE_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GITG_FILES_TYPE_TREE_STORE))
#define GITG_FILES_TREE_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GITG_FILES_TYPE_TREE_STORE, GitgFilesTreeStoreClass))

typedef struct _GitgFilesTreeStore GitgFilesTreeStore;
typedef struct _GitgFilesTreeStoreClass GitgFilesTreeStoreClass;
typedef struct _GitgFilesTreeStorePrivate GitgFilesTreeStorePrivate;

struct _GitgFilesPanel {
	GObject parent_instance;
	GitgFilesPanelPrivate * priv;
};

struct _GitgFilesPanelClass {
	GObjectClass parent_class;
	guint* (*get_shortcut) (GitgFilesPanel* self);
};

struct _GitgFilesTreeStore {
	GtkTreeStore parent_instance;
	GitgFilesTreeStorePrivate * priv;
};

struct _GitgFilesTreeStoreClass {
	GtkTreeStoreClass parent_class;
};

GType gitg_files_panel_register_type (GTypeModule * module);
VALA_EXTERN GType gitg_files_panel_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgFilesPanel, g_object_unref)
VALA_EXTERN GitgFilesPanel* gitg_files_panel_new (void);
VALA_EXTERN GitgFilesPanel* gitg_files_panel_construct (GType object_type);
VALA_EXTERN guint* gitg_files_panel_get_shortcut (GitgFilesPanel* self);
VALA_EXTERN void peas_register_types (GTypeModule* module);
GType gitg_files_tree_store_register_type (GTypeModule * module);
VALA_EXTERN GType gitg_files_tree_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GitgFilesTreeStore, g_object_unref)
VALA_EXTERN GgitOId* gitg_files_tree_store_get_id (GitgFilesTreeStore* self,
                                       GtkTreeIter* iter);
VALA_EXTERN gchar* gitg_files_tree_store_get_full_path (GitgFilesTreeStore* self,
                                            GtkTreeIter* iter);
VALA_EXTERN gchar* gitg_files_tree_store_get_name (GitgFilesTreeStore* self,
                                       GtkTreeIter* iter);
VALA_EXTERN gboolean gitg_files_tree_store_get_isdir (GitgFilesTreeStore* self,
                                          GtkTreeIter* iter);
VALA_EXTERN GitgFilesTreeStore* gitg_files_tree_store_new (void);
VALA_EXTERN GitgFilesTreeStore* gitg_files_tree_store_construct (GType object_type);
VALA_EXTERN GgitTree* gitg_files_tree_store_get_tree (GitgFilesTreeStore* self);
VALA_EXTERN void gitg_files_tree_store_set_tree (GitgFilesTreeStore* self,
                                     GgitTree* value);

G_END_DECLS

#endif
